@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -44,18 +44,18 @@ static char THIS_FILE[] = __FILE__;
 #define max(a,b) ((a)>(b))?(a):(b)
 
 BEGIN_EVENT_TABLE(COScopeCtrl, wxControl)
-EVT_PAINT(COScopeCtrl:: OnPaint)
-EVT_SIZE(COScopeCtrl:: OnSize)
-EVT_TIMER(TIMER_OSCOPE, COScopeCtrl:: OnTimer)
+EVT_PAINT(COScopeCtrl::OnPaint)
+EVT_SIZE(COScopeCtrl::OnSize)
+EVT_TIMER(TIMER_OSCOPE, COScopeCtrl::OnTimer)
 END_EVENT_TABLE()
 
 /////////////////////////////////////////////////////////////////////////////
 // COScopeCtrl
-COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
-: wxControl(parent, - 1, wxDefaultPosition, wxDefaultSize), m_nRedrawTimer(this, TIMER_OSCOPE) 
+COScopeCtrl::COScopeCtrl(int NTrends, wxWindow *parent)
+: wxControl(parent, - 1, wxDefaultPosition, wxDefaultSize), m_nRedrawTimer(this, TIMER_OSCOPE)
 {
     int i;
-    COLORREF PresetColor [ 16 ] = 
+    COLORREF PresetColor [ 16 ] =
     {
         RGB(0xFF, 0x00, 0x00),
         RGB(0xFF, 0xC0, 0xC0),
@@ -73,8 +73,7 @@ COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
         RGB(0xA0, 0x00, 0xA0),
         RGB(0xFF, 0xFF, 0xFF),
         RGB(0x80, 0x80, 0x80)
-    }
-    ;
+        };
     // since plotting is based on a LineTo for each new point
     // we need a starting point (i.e. a "previous" point)
     // use 0.0 as the default first point.
@@ -89,7 +88,7 @@ COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
     m_dcGrid = NULL;
     m_bitmapPlot = NULL;
     m_bitmapGrid = NULL;
-    for (i = 0 ; i < m_NTrends ; i++) 
+    for (i = 0 ; i < m_NTrends ; i++)
     {
         if (i < 15)
         // see also SetPlotColor:
@@ -98,7 +97,7 @@ COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
         // see also SetPlotColor:
         m_PlotData[ i ].crPlotColor = RGB(255, 255, 255);
         //m_PlotData[ i ].penPlot.CreatePen(PS_SOLID, 0, m_PlotData[ i ].crPlotColor ) ;
-        m_PlotData[i].penPlot = * (wxThePenList -> FindOrCreatePen(wxColour(GetRValue(m_PlotData[i].crPlotColor), GetGValue(m_PlotData[i].crPlotColor), GetBValue(m_PlotData[i].crPlotColor)), 1, wxSOLID));
+        m_PlotData[i].penPlot = * (wxThePenList->FindOrCreatePen(wxColour(GetRValue(m_PlotData[i].crPlotColor), GetGValue(m_PlotData[i].crPlotColor), GetBValue(m_PlotData[i].crPlotColor)), 1, wxSOLID));
         m_PlotData[ i ].dPreviousPosition = 0.0;
         m_PlotData[ i ].nPrevY = - 1;
         m_PlotData[ i ].dLowerLimit = - 10.0;
@@ -139,13 +138,13 @@ COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
     // see also SetGridColor:
     m_crGridColor = RGB(0, 255, 255);
     // protected variables
-    m_brushBack = * (wxTheBrushList -> FindOrCreateBrush(wxColour(GetRValue(m_crBackColor), GetGValue(m_crBackColor), GetBValue(m_crBackColor)), wxSOLID));
+    m_brushBack = * (wxTheBrushList->FindOrCreateBrush(wxColour(GetRValue(m_crBackColor), GetGValue(m_crBackColor), GetBValue(m_crBackColor)), wxSOLID));
     //*wxBLACK_BRUSH;//.CreateSolidBrush( m_crBackColor ) ;
     // public member variables, can be set directly
     // can also be set with SetXUnits:
-    m_str.XUnits.Format("Samples");
+    m_str.XUnits.Printf("Samples");
     // can also be set with SetYUnits:
-    m_str.YUnits.Format("Y units");
+    m_str.YUnits.Printf("Y units");
     // protected bitmaps to restore the memory DC's
     m_pbitmapOldGrid = NULL;
     m_pbitmapOldPlot = NULL;
@@ -161,14 +160,14 @@ COScopeCtrl:: COScopeCtrl(int NTrends, wxWindow *parent)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-COScopeCtrl:: ~COScopeCtrl() 
+COScopeCtrl::~COScopeCtrl()
 {
     // just to be picky restore the bitmaps for the two memory dc's
     // (these dc's are being destroyed so there shouldn't be any leaks)
     if (m_pbitmapOldGrid != NULL)
-    m_dcGrid -> SelectObject(wxNullBitmap);
+    m_dcGrid->SelectObject(wxNullBitmap);
     if (m_pbitmapOldPlot != NULL)
-    m_dcPlot -> SelectObject(wxNullBitmap);
+    m_dcPlot->SelectObject(wxNullBitmap);
     delete [] m_PlotData;
     delete m_dcGrid;
     delete m_dcPlot;
@@ -193,15 +192,15 @@ END_MESSAGE_MAP()
 
 /////////////////////////////////////////////////////////////////////////////
 #if 0
-BOOL COScopeCtrl:: Create(DWORD dwStyle, const RECT &rect,
-CWnd *pParentWnd, UINT nID) 
+BOOL COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
+CWnd *pParentWnd, UINT nID)
 {
     BOOL result;
     static CString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
-    result = CWnd:: CreateEx(WS_EX_CLIENTEDGE | WS_EX_STATICEDGE,
+    result = CWnd::CreateEx(WS_EX_CLIENTEDGE | WS_EX_STATICEDGE,
     className, NULL, dwStyle,
     rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-    pParentWnd -> GetSafeHwnd(), (HMENU) nID);
+    pParentWnd->GetSafeHwnd(), (HMENU) nID);
     if (result != 0)
     InvalidateCtrl();
     return result;
@@ -211,7 +210,7 @@ CWnd *pParentWnd, UINT nID)
 #endif
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: SetRange(double dLower, double dUpper, int iTrend) 
+void COScopeCtrl::SetRange(double dLower, double dUpper, int iTrend)
 {
     m_PlotData[ iTrend ].dLowerLimit = dLower;
     m_PlotData[ iTrend ].dUpperLimit = dUpper;
@@ -222,10 +221,10 @@ void COScopeCtrl:: SetRange(double dLower, double dUpper, int iTrend)
     // SetRange:
 }
 
-void COScopeCtrl:: SetRanges(double dLower, double dUpper) 
+void COScopeCtrl::SetRanges(double dLower, double dUpper)
 {
     int iTrend;
-    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
     {
         m_PlotData[ iTrend ].dLowerLimit = dLower;
         m_PlotData[ iTrend ].dUpperLimit = dUpper;
@@ -241,7 +240,7 @@ void COScopeCtrl:: SetRanges(double dLower, double dUpper)
 // G.Hayduk: Apart from setting title of axis, now you can optionally set
 // the limits strings
 // (string which will be placed on the left and right of axis)
-void COScopeCtrl:: SetXUnits(CString string, CString XMin, CString XMax) 
+void COScopeCtrl::SetXUnits(wxString string, wxString XMin, wxString XMax)
 {
     m_str.XUnits = string;
     m_str.XMin = XMin;
@@ -254,7 +253,7 @@ void COScopeCtrl:: SetXUnits(CString string, CString XMin, CString XMax)
 // G.Hayduk: Apart from setting title of axis, now you can optionally set
 // the limits strings
 // (string which will be placed on the bottom and top of axis)
-void COScopeCtrl:: SetYUnits(CString string, CString YMin, CString YMax) 
+void COScopeCtrl::SetYUnits(wxString string, wxString YMin, wxString YMax)
 {
     m_str.YUnits = string;
     m_str.YMin = YMin;
@@ -265,7 +264,7 @@ void COScopeCtrl:: SetYUnits(CString string, CString YMin, CString YMax)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: SetGridColor(COLORREF color) 
+void COScopeCtrl::SetGridColor(COLORREF color)
 {
     m_crGridColor = color;
     // clear out the existing garbage, re-start with a clean plot
@@ -274,37 +273,37 @@ void COScopeCtrl:: SetGridColor(COLORREF color)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: SetPlotColor(COLORREF color, int iTrend) 
+void COScopeCtrl::SetPlotColor(COLORREF color, int iTrend)
 {
     m_PlotData[ iTrend ].crPlotColor = color;
     //m_PlotData[ iTrend ].penPlot.DeleteObject() ;
-    m_PlotData[ iTrend ].penPlot = * (wxThePenList -> FindOrCreatePen(wxColour(GetRValue(m_PlotData[iTrend].crPlotColor), GetGValue(m_PlotData[iTrend].crPlotColor), GetBValue(m_PlotData[iTrend].crPlotColor)), 1, wxSOLID));
+    m_PlotData[ iTrend ].penPlot = * (wxThePenList->FindOrCreatePen(wxColour(GetRValue(m_PlotData[iTrend].crPlotColor), GetGValue(m_PlotData[iTrend].crPlotColor), GetBValue(m_PlotData[iTrend].crPlotColor)), 1, wxSOLID));
     //CreatePen(PS_SOLID, 0, m_PlotData[ iTrend ].crPlotColor) ;
     // clear out the existing garbage, re-start with a clean plot
     //	InvalidateCtrl() ;
     // SetPlotColor:
 }
 
-COLORREF COScopeCtrl:: GetPlotColor(int iTrend) 
+COLORREF COScopeCtrl::GetPlotColor(int iTrend)
 {
     return m_PlotData[ iTrend ].crPlotColor;
     // GetPlotColor:
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: SetBackgroundColor(COLORREF color) 
+void COScopeCtrl::SetBackgroundColor(COLORREF color)
 {
     m_crBackColor = color;
     //m_brushBack.DeleteObject() ;
     //m_brushBack.CreateSolidBrush(m_crBackColor) ;
-    m_brushBack = * (wxTheBrushList -> FindOrCreateBrush(wxColour(GetRValue(m_crBackColor), GetGValue(m_crBackColor), GetBValue(m_crBackColor)), wxSOLID));
+    m_brushBack = * (wxTheBrushList->FindOrCreateBrush(wxColour(GetRValue(m_crBackColor), GetGValue(m_crBackColor), GetBValue(m_crBackColor)), wxSOLID));
     // clear out the existing garbage, re-start with a clean plot
     InvalidateCtrl();
     // SetBackgroundColor:
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: InvalidateCtrl(bool deleteGraph) 
+void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
 {
     // There is a lot of drawing going on here - particularly in terms of
     // drawing the grid.  Don't panic, this is all being drawn (only once)
@@ -316,27 +315,27 @@ void COScopeCtrl:: InvalidateCtrl(bool deleteGraph)
     return;
     wxPen *oldPen;
     //CPen solidPen(PS_SOLID, 0, m_crGridColor) ;
-    wxPen solidPen = * (wxThePenList -> FindOrCreatePen(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)), 1, wxSOLID));
+    wxPen solidPen = * (wxThePenList->FindOrCreatePen(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)), 1, wxSOLID));
     //wxFont axisFont, yUnitFont, *oldFont ;
-    CString strTemp;
+    wxString strTemp;
     // in case we haven't established the memory dc's
     //CClientDC dc(this) ;
     wxClientDC dc(this);
     // if we don't have one yet, set up a memory dc for the grid
-    if (m_dcGrid == NULL) 
+    if (m_dcGrid == NULL)
     {
         //m_dcGrid.CreateCompatibleDC(&dc) ;
         m_dcGrid = new wxMemoryDC;
         if (m_bitmapGrid) delete m_bitmapGrid;
         m_bitmapGrid = NULL;
         m_bitmapGrid = new wxBitmap(m_nClientWidth, m_nClientHeight);
-        m_dcGrid -> SelectObject( *m_bitmapGrid);
+        m_dcGrid->SelectObject( *m_bitmapGrid);
     }
     //m_dcGrid.SetBkColor (m_crBackColor) ;
     // fill the grid background
-    m_dcGrid -> SetBrush(m_brushBack);
-    m_dcGrid -> SetPen( *wxTRANSPARENT_PEN);
-    m_dcGrid -> DrawRectangle(m_rectClient.left, m_rectClient.top, m_rectClient.right - m_rectClient.left,
+    m_dcGrid->SetBrush(m_brushBack);
+    m_dcGrid->SetPen( *wxTRANSPARENT_PEN);
+    m_dcGrid->DrawRectangle(m_rectClient.left, m_rectClient.top, m_rectClient.right - m_rectClient.left,
     m_rectClient.bottom - m_rectClient.top);
     //m_dcGrid.FillRect(m_rectClient, &m_brushBack) ;
     // draw the plot rectangle:
@@ -355,7 +354,7 @@ void COScopeCtrl:: InvalidateCtrl(bool deleteGraph)
     m_nPlotWidth = m_rectPlot.right - m_rectPlot.left;
     // draw the plot rectangle
     //oldPen = m_dcGrid.SelectObject (&solidPen) ;
-    m_dcGrid -> SetPen(solidPen);
+    m_dcGrid->SetPen(solidPen);
 #if 0
     m_dcGrid.MoveTo(m_rectPlot.left, m_rectPlot.top);
     m_dcGrid.LineTo(m_rectPlot.right + 1, m_rectPlot.top);
@@ -364,23 +363,23 @@ void COScopeCtrl:: InvalidateCtrl(bool deleteGraph)
     m_dcGrid.LineTo(m_rectPlot.left, m_rectPlot.top);
     m_dcGrid.SelectObject(oldPen);
 #endif
-    m_dcGrid -> DrawLine(m_rectPlot.left, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.top);
-    m_dcGrid -> DrawLine(m_rectPlot.right + 1, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.bottom + 1);
-    m_dcGrid -> DrawLine(m_rectPlot.right + 1, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.bottom + 1);
-    m_dcGrid -> DrawLine(m_rectPlot.left, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.top);
-    m_dcGrid -> SetPen(wxNullPen);
+    m_dcGrid->DrawLine(m_rectPlot.left, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.top);
+    m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.bottom + 1);
+    m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.bottom + 1);
+    m_dcGrid->DrawLine(m_rectPlot.left, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.top);
+    m_dcGrid->SetPen(wxNullPen);
     // draw the dotted lines,
     // use SetPixel instead of a dotted pen - this allows for a
     // finer dotted line and a more "technical" look
     // G.Hayduk: added configurable number of grids
     wxPen grPen(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)), 1, wxSOLID);
-    m_dcGrid -> SetPen(grPen);
-    for (j = 1 ; j < (m_nYGrids + 1) ; j++) 
+    m_dcGrid->SetPen(grPen);
+    for (j = 1 ; j < (m_nYGrids + 1) ; j++)
     {
         GridPos = (m_rectPlot.bottom - m_rectPlot.top) *j/ (m_nYGrids + 1) + m_rectPlot.top;
         for (i = m_rectPlot.left ; i < m_rectPlot.right ; i += 4)
         //m_dcGrid.SetPixel ( i, GridPos, m_crGridColor ) ;
-        m_dcGrid -> DrawPoint(i, GridPos);
+        m_dcGrid->DrawPoint(i, GridPos);
     }
  /*
  for( j=1 ; j<(m_nXGrids+1) ; j++ ){
@@ -411,13 +410,13 @@ void COScopeCtrl:: InvalidateCtrl(bool deleteGraph)
     // grab the horizontal font
     //oldFont = m_dcGrid.SelectObject(&axisFont) ;
     //,this);:
-    m_dcGrid -> SetFont( *axisFont);
+    m_dcGrid->SetFont( *axisFont);
     // y max
     //m_dcGrid.SetTextColor (m_crGridColor) ;
-    m_dcGrid -> SetTextForeground(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)));
+    m_dcGrid->SetTextForeground(wxColour(GetRValue(m_crGridColor), GetGValue(m_crGridColor), GetBValue(m_crGridColor)));
     //m_dcGrid.SetTextAlign (TA_RIGHT|TA_TOP) ;
     if (m_str.YMax.IsEmpty())
-    strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit);
+    strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit);
     else
     strTemp = m_str.YMax;
     //m_dcGrid.TextOut (m_rectPlot.left-4, m_rectPlot.top-7, strTemp) ;
@@ -426,40 +425,40 @@ void COScopeCtrl:: InvalidateCtrl(bool deleteGraph)
 #if (wxMAJOR_VERSION==2) && (wxMINOR_VERSION==4) && (wxRELEASE_NUMBER==0)
     // well.. it doesn't work. so don't do it
 #else
-    m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
-    m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.top - 7);
+    m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
+    m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.top - 7);
 #endif
 #else
-m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
+m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
 
-m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.top - 7);
+m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.top - 7);
 
 #endif
-m_dcGrid -> SetPen(wxNullPen);
+m_dcGrid->SetPen(wxNullPen);
 
 // y/2
-strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit / 2);
+strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dUpperLimit / 2);
 
 //m_dcGrid.TextOut (m_rectPlot.left-2, m_rectPlot.bottom+((m_rectPlot.top-m_rectPlot.bottom)/2)-7 , strTemp) ;
 #ifdef __WXGTK20__
 #if (wxMAJOR_VERSION==2) && (wxMINOR_VERSION==4) && (wxRELEASE_NUMBER==0)
 // it doesn't work. so don't do it.
 #else
-m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
+m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
 
-m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 2 - sizX, m_rectPlot.bottom + ((m_rectPlot.top - m_rectPlot.bottom) /2) - 7);
+m_dcGrid->DrawText(strTemp, m_rectPlot.left - 2 - sizX, m_rectPlot.bottom + ((m_rectPlot.top - m_rectPlot.bottom) /2) - 7);
 
 #endif
 #else
-m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
+m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
 
-m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 2 - sizX, m_rectPlot.bottom + ((m_rectPlot.top - m_rectPlot.bottom) /2) - 7);
+m_dcGrid->DrawText(strTemp, m_rectPlot.left - 2 - sizX, m_rectPlot.bottom + ((m_rectPlot.top - m_rectPlot.bottom) /2) - 7);
 
 #endif
 // y min
 //m_dcGrid.SetTextAlign (TA_RIGHT|TA_BASELINE) ;
 if (m_str.YMin.IsEmpty())
-strTemp.Format("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dLowerLimit);
+strTemp.Printf("%.*lf", m_nYDecimals, m_PlotData[ 0 ].dLowerLimit);
 
 else
 strTemp = m_str.YMin;
@@ -468,16 +467,16 @@ strTemp = m_str.YMin;
 #if (wxMAJOR_VERSION==2) && (wxMINOR_VERSION==4) && (wxRELEASE_NUMBER==0)
 // well.. it doesn't work. so don't do it
 #else
-m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
+m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
 
-m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
+m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
 
 //m_dcGrid.TextOut (m_rectPlot.left-4-sizX, m_rectPlot.bottom, strTemp) ;
 #endif
 #else
-m_dcGrid -> GetTextExtent(strTemp, &sizX, &sizY);
+m_dcGrid->GetTextExtent(strTemp, &sizX, &sizY);
 
-m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
+m_dcGrid->DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
 
 #endif
  /*
@@ -505,20 +504,20 @@ m_dcGrid -> DrawText(strTemp, m_rectPlot.left - 4 - sizX, m_rectPlot.bottom);
 #if (wxMAJOR_VERSION==2) && (wxMINOR_VERSION==4) && (wxRELEASE_NUMBER==0)
 // well.. it doesn't work. so don't do it
 #else
-m_dcGrid -> GetTextExtent(m_str.XUnits, &sizX, &sizY);
+m_dcGrid->GetTextExtent(m_str.XUnits, &sizX, &sizY);
 
 //m_dcGrid.TextOut ((m_rectPlot.left+m_rectPlot.right)/2,
 //	                m_rectPlot.bottom+4, m_str.XUnits) ;
-m_dcGrid -> DrawText(m_str.XUnits, (m_rectPlot.left + m_rectPlot.right) /2 - sizX/2, m_rectPlot.bottom + 4);
+m_dcGrid->DrawText(m_str.XUnits, (m_rectPlot.left + m_rectPlot.right) /2 - sizX/2, m_rectPlot.bottom + 4);
 
 #endif
 #else
-m_dcGrid -> GetTextExtent(m_str.XUnits, &sizX, &sizY);
+m_dcGrid->GetTextExtent(m_str.XUnits, &sizX, &sizY);
 
 //m_dcGrid.TextOut ((m_rectPlot.left+m_rectPlot.right)/2,
 //	                m_rectPlot.bottom+4, m_str.XUnits) ;
 if (!m_str.XUnits.IsEmpty())
-m_dcGrid -> DrawText(m_str.XUnits, (m_rectPlot.left + m_rectPlot.right) /2 - sizX/2, m_rectPlot.bottom + 4);
+m_dcGrid->DrawText(m_str.XUnits, (m_rectPlot.left + m_rectPlot.right) /2 - sizX/2, m_rectPlot.bottom + 4);
 
 #endif
 // restore the font
@@ -529,10 +528,10 @@ m_dcGrid -> DrawText(m_str.XUnits, (m_rectPlot.left + m_rectPlot.right) /2 - siz
 //m_dcGrid.SetTextAlign (TA_CENTER|TA_BASELINE) ;
 //m_dcGrid.TextOut ((m_rectClient.left+m_rectPlot.left)/2,
 //	                ((m_rectPlot.bottom+m_rectPlot.top)/2)-40, m_str.YUnits) ;
-m_dcGrid -> GetTextExtent(m_str.YUnits, &sizX, &sizY);
+m_dcGrid->GetTextExtent(m_str.YUnits, &sizX, &sizY);
 
 if (!m_str.YUnits.IsEmpty())
-m_dcGrid -> DrawRotatedText(m_str.YUnits, (m_rectClient.left + m_rectPlot.left + 4) /2 - (sizY *2),
+m_dcGrid->DrawRotatedText(m_str.YUnits, (m_rectClient.left + m_rectPlot.left + 4) /2 - (sizY *2),
 ((m_rectPlot.bottom + m_rectPlot.top) /2) + sizX/2, 90.0);
 
 //m_dcGrid.SelectObject(oldFont) ;
@@ -541,27 +540,27 @@ m_dcGrid -> DrawRotatedText(m_str.YUnits, (m_rectClient.left + m_rectPlot.left +
 // no more drawing to this bitmap is needed until the setting are changed
 
 // if we don't have one yet, set up a memory dc for the plot
-if (m_dcPlot == NULL) 
+if (m_dcPlot == NULL)
 {
     // what on earth was going on in here??
     m_dcPlot = new wxMemoryDC;
     if (m_bitmapPlot) delete m_bitmapPlot;
     m_bitmapPlot = NULL;
     m_bitmapPlot = new wxBitmap(m_nClientWidth, m_nClientHeight);
-    m_dcPlot -> SelectObject( *m_bitmapPlot);
+    m_dcPlot->SelectObject( *m_bitmapPlot);
 }
 
 // make sure the plot bitmap is cleared
-if (deleteGraph) 
+if (deleteGraph)
 {
     //m_dcPlot.SetBkColor (m_crBackColor) ;
-    m_dcPlot -> SetBrush(m_brushBack);
-    m_dcPlot -> SetPen( *wxTRANSPARENT_PEN);
-    m_dcPlot -> DrawRectangle(m_rectClient.left, m_rectClient.top, m_rectClient.right - m_rectClient.left,
+    m_dcPlot->SetBrush(m_brushBack);
+    m_dcPlot->SetPen( *wxTRANSPARENT_PEN);
+    m_dcPlot->DrawRectangle(m_rectClient.left, m_rectClient.top, m_rectClient.right - m_rectClient.left,
     m_rectClient.bottom - m_rectClient.top);
 }
 
-if (true) 
+if (true)
 {
     int iNewSize = m_rectClient.right - m_rectClient.left;
     if (m_nMaxPointCnt < iNewSize)
@@ -597,23 +596,23 @@ Refresh(FALSE, &rrc);
 
 /////////////////////////////////////////////////////////////////////////////
 // G.Hayduk: now, there are two methods: AppendPoints and AppendEmptyPoints
-void COScopeCtrl:: AppendPoints(double dNewPoint[], bool bInvalidate, bool bAdd2List) 
+void COScopeCtrl::AppendPoints(double dNewPoint[], bool bInvalidate, bool bAdd2List)
 {
     int iTrend;
     // append a data point to the plot
-    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
     {
         m_PlotData[iTrend].dCurrentPosition = dNewPoint[iTrend];
-        if (bAdd2List) 
+        if (bAdd2List)
         {
             m_PlotData[iTrend].lstPoints.AddTail((float) dNewPoint[iTrend]);
             while (m_PlotData[iTrend].lstPoints.GetCount() > m_nMaxPointCnt)
             m_PlotData[iTrend].lstPoints.RemoveHead();
         }
     }
-    if (m_nTrendPoints > 0) 
+    if (m_nTrendPoints > 0)
     {
-        if (CustShift.m_nPointsToDo == 0) 
+        if (CustShift.m_nPointsToDo == 0)
         {
             CustShift.m_nPointsToDo = m_nTrendPoints - 1;
             CustShift.m_nWidthToDo = m_nPlotWidth;
@@ -642,21 +641,21 @@ void COScopeCtrl:: AppendPoints(double dNewPoint[], bool bInvalidate, bool bAdd2
 // for first valid vector of data points, and then call AppendPoints again and again
 // for valid points
 
-void COScopeCtrl:: AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool bAdd2List) 
+void COScopeCtrl::AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool bAdd2List)
 {
     int iTrend, currY;
     RECT ScrollRect, rectCleanUp;
     // append a data point to the plot
     // return the previous point
-    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
     {
         m_PlotData[ iTrend ].dCurrentPosition = dNewPoint[ iTrend ];
         if (bAdd2List)
         m_PlotData[iTrend].lstPoints.AddTail(dNewPoint[iTrend]);
     }
-    if (m_nTrendPoints > 0) 
+    if (m_nTrendPoints > 0)
     {
-        if (CustShift.m_nPointsToDo == 0) 
+        if (CustShift.m_nPointsToDo == 0)
         {
             CustShift.m_nPointsToDo = m_nTrendPoints - 1;
             CustShift.m_nWidthToDo = m_nPlotWidth;
@@ -670,9 +669,9 @@ void COScopeCtrl:: AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool
         CustShift.m_nPointsToDo--;
     }
     // now comes DrawPoint's shift process
-    if (m_dcPlot != NULL) 
+    if (m_dcPlot != NULL)
     {
-        if (m_nShiftPixels > 0) 
+        if (m_nShiftPixels > 0)
         {
             ScrollRect.left = m_rectPlot.left;
             ScrollRect.top = m_rectPlot.top + 1;
@@ -682,7 +681,7 @@ void COScopeCtrl:: AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool
             ScrollRect.right++;
             // no scroll in wxWin
             //m_dcPlot.ScrollDC( -m_nShiftPixels, 0, (LPCRECT)&ScrollRect, (LPCRECT)&ScrollRect, NULL, NULL );
-            m_dcPlot -> Blit(m_rectPlot.left, m_rectPlot.top + 1, m_nPlotWidth, m_nPlotHeight, m_dcPlot,
+            m_dcPlot->Blit(m_rectPlot.left, m_rectPlot.top + 1, m_nPlotWidth, m_nPlotHeight, m_dcPlot,
             m_rectPlot.left + m_nShiftPixels, m_rectPlot.top + 1);
             // establish a rectangle over the right side of plot
             // which now needs to be cleaned up proir to adding the new point
@@ -691,13 +690,13 @@ void COScopeCtrl:: AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool
             rectCleanUp.right++;
             // fill the cleanup area with the background
             //m_dcPlot.FillRect(rectCleanUp, &m_brushBack) ;
-            m_dcPlot -> SetBrush(m_brushBack);
-            m_dcPlot -> SetPen( *wxTRANSPARENT_PEN);
-            m_dcPlot -> DrawRectangle(rectCleanUp.left, rectCleanUp.top, rectCleanUp.right - rectCleanUp.left,
+            m_dcPlot->SetBrush(m_brushBack);
+            m_dcPlot->SetPen( *wxTRANSPARENT_PEN);
+            m_dcPlot->DrawRectangle(rectCleanUp.left, rectCleanUp.top, rectCleanUp.right - rectCleanUp.left,
             rectCleanUp.bottom - rectCleanUp.top);
         }
         // draw the next line segement
-        for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+        for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
         {
             currY = m_rectPlot.bottom -
             (long)((m_PlotData[ iTrend ].dCurrentPosition - m_PlotData[ iTrend ].dLowerLimit) *m_PlotData[ iTrend ].dVerticalFactor);
@@ -715,7 +714,7 @@ void COScopeCtrl:: AppendEmptyPoints(double dNewPoint[], bool bInvalidate, bool
 }
 
 ////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: OnPaint(wxPaintEvent &evt) 
+void COScopeCtrl::OnPaint(wxPaintEvent &evt)
 {
     // device context for painting:
     wxPaintDC dc(this);
@@ -732,7 +731,7 @@ void COScopeCtrl:: OnPaint(wxPaintEvent &evt)
     memBitmap = new wxBitmap(m_nClientWidth, m_nClientHeight);
     //oldBitmap = (CBitmap *)memDC.SelectObject(&memBitmap) ;
     memDC.SelectObject( *memBitmap);
-    if (memDC.Ok()) 
+    if (memDC.Ok())
     {
         // first drop the grid on the memory dc
         //memDC.BitBlt(0, 0, m_nClientWidth, m_nClientHeight,
@@ -756,7 +755,7 @@ void COScopeCtrl:: OnPaint(wxPaintEvent &evt)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: DrawPoint() 
+void COScopeCtrl::DrawPoint()
 {
     // this does the work of "scrolling" the plot to the left
     // and appending a new data point all of the plotting is
@@ -765,14 +764,14 @@ void COScopeCtrl:: DrawPoint()
     int currX, prevX, currY, prevY, iTrend;
     //CPen *oldPen ;
     RECT ScrollRect, rectCleanUp;
-    if (m_dcPlot != NULL) 
+    if (m_dcPlot != NULL)
     {
         //	BitBlt was replaced by call to ScrollDC
         //		m_dcPlot.BitBlt(m_rectPlot.left, m_rectPlot.top+1,
         //		                m_nPlotWidth, m_nPlotHeight, &m_dcPlot,
         //		                m_rectPlot.left+m_nShiftPixels, m_rectPlot.top+1,
         //		                SRCCOPY) ;
-        if (m_nShiftPixels > 0) 
+        if (m_nShiftPixels > 0)
         {
             ScrollRect.left = m_rectPlot.left;
             ScrollRect.top = m_rectPlot.top + 1;
@@ -782,7 +781,7 @@ void COScopeCtrl:: DrawPoint()
             ScrollRect.right++;
             // no scroll in wxWIn
             //m_dcPlot.ScrollDC( -m_nShiftPixels, 0, (LPCRECT)&ScrollRect, (LPCRECT)&ScrollRect, NULL, NULL );
-            m_dcPlot -> Blit(m_rectPlot.left, m_rectPlot.top + 1, m_nPlotWidth, m_nPlotHeight, m_dcPlot,
+            m_dcPlot->Blit(m_rectPlot.left, m_rectPlot.top + 1, m_nPlotWidth, m_nPlotHeight, m_dcPlot,
             m_rectPlot.left + m_nShiftPixels, m_rectPlot.top + 1);
             //printf("TODO: Scroll\n");
             // establish a rectangle over the right side of plot
@@ -792,21 +791,21 @@ void COScopeCtrl:: DrawPoint()
             rectCleanUp.left = rectCleanUp.right - m_nShiftPixels;
             rectCleanUp.right++;
             // fill the cleanup area with the background
-            m_dcPlot -> SetPen( *wxTRANSPARENT_PEN);
-            m_dcPlot -> SetBrush(m_brushBack);
-            m_dcPlot -> DrawRectangle(rectCleanUp.left, rectCleanUp.top, rectCleanUp.right - rectCleanUp.left,
+            m_dcPlot->SetPen( *wxTRANSPARENT_PEN);
+            m_dcPlot->SetBrush(m_brushBack);
+            m_dcPlot->DrawRectangle(rectCleanUp.left, rectCleanUp.top, rectCleanUp.right - rectCleanUp.left,
             rectCleanUp.bottom - rectCleanUp.top);
             //m_dcPlot.FillRect(rectCleanUp, &m_brushBack) ;
         }
         // draw the next line segement
-        for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+        for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
         {
             // grab the plotting pen
             //oldPen = m_dcPlot.SelectObject(&m_PlotData[ iTrend ].penPlot) ;
-            m_dcPlot -> SetPen(m_PlotData[iTrend].penPlot);
+            m_dcPlot->SetPen(m_PlotData[iTrend].penPlot);
             // move to the previous point
             prevX = m_rectPlot.right - m_nShiftPixels;
-            if (m_PlotData[ iTrend ].nPrevY > 0) 
+            if (m_PlotData[ iTrend ].nPrevY > 0)
             {
                 prevY = m_PlotData[ iTrend ].nPrevY;
             }
@@ -822,18 +821,18 @@ void COScopeCtrl:: DrawPoint()
             currY = m_rectPlot.bottom -
             (long)((m_PlotData[ iTrend ].dCurrentPosition - m_PlotData[ iTrend ].dLowerLimit) *m_PlotData[ iTrend ].dVerticalFactor);
             m_PlotData[ iTrend ].nPrevY = currY;
-            if (abs(prevX - currX) > abs(prevY - currY)) 
+            if (abs(prevX - currX) > abs(prevY - currY))
             {
                 currX += prevX - currX > 0 ? - 1: 1;
             }
-            else 
+            else
             {
                 currY += prevY - currY > 0 ? - 1: 1;
             }
             //m_dcPlot.LineTo (currX-1, currY) ;
-            m_dcPlot -> DrawLine(sX, sY, currX - 1, currY);
+            m_dcPlot->DrawLine(sX, sY, currX - 1, currY);
             //if (drawBars) m_dcPlot.LineTo(currX-1,m_rectPlot.bottom);
-            if (drawBars) m_dcPlot -> DrawLine(currX - 1, currY, currX - 1, m_rectPlot.bottom);
+            if (drawBars) m_dcPlot->DrawLine(currX - 1, currY, currX - 1, m_rectPlot.bottom);
             //m_dcPlot.Rectangle(currX-1,currY,currX-1,m_rectPlot.bottom);
             // restore the pen
             //m_dcPlot.SelectObject(oldPen) ;
@@ -841,19 +840,19 @@ void COScopeCtrl:: DrawPoint()
             // fill the upper and lower leakage with the background
             // this will facilitate clipping on an as needed basis
             // as opposed to always calling IntersectClipRect
-            if ((prevY <= m_rectPlot.top) || (currY <= m_rectPlot.top)) 
+            if ((prevY <= m_rectPlot.top) || (currY <= m_rectPlot.top))
             {
                 //m_dcPlot.FillRect(CRect(prevX-1, m_rectClient.top, currX+5, m_rectPlot.top+1), &m_brushBack) ;
-                m_dcPlot -> SetBrush(m_brushBack);
-                m_dcPlot -> SetPen( *wxTRANSPARENT_PEN);
-                m_dcPlot -> DrawRectangle(prevX - 1, m_rectClient.top, (currX + 5) - (prevX - 1), (m_rectPlot.top + 1) - (m_rectClient.top));
+                m_dcPlot->SetBrush(m_brushBack);
+                m_dcPlot->SetPen( *wxTRANSPARENT_PEN);
+                m_dcPlot->DrawRectangle(prevX - 1, m_rectClient.top, (currX + 5) - (prevX - 1), (m_rectPlot.top + 1) - (m_rectClient.top));
             }
-            if ((prevY >= m_rectPlot.bottom) || (currY >= m_rectPlot.bottom)) 
+            if ((prevY >= m_rectPlot.bottom) || (currY >= m_rectPlot.bottom))
             {
                 //m_dcPlot.FillRect(CRect(prevX-1, m_rectPlot.bottom+1, currX+5, m_rectClient.bottom+1), &m_brushBack) ;
-                m_dcPlot -> SetBrush(m_brushBack);
-                m_dcPlot -> SetPen( *wxTRANSPARENT_PEN);
-                m_dcPlot -> DrawRectangle(prevX - 1, m_rectPlot.bottom + 1, (currX + 5) - (prevX - 1), (m_rectClient.bottom + 1) - (m_rectPlot.bottom + 1));
+                m_dcPlot->SetBrush(m_brushBack);
+                m_dcPlot->SetPen( *wxTRANSPARENT_PEN);
+                m_dcPlot->DrawRectangle(prevX - 1, m_rectPlot.bottom + 1, (currX + 5) - (prevX - 1), (m_rectClient.bottom + 1) - (m_rectPlot.bottom + 1));
             }
             // store the current point for connection to the next point
             m_PlotData[ iTrend ].dPreviousPosition = m_PlotData[ iTrend ].dCurrentPosition;
@@ -864,17 +863,17 @@ void COScopeCtrl:: DrawPoint()
 
 /////////////////////////////////////////////////////////////////////////////
 //UINT nType, int cx, int cy):
-void COScopeCtrl:: OnSize(wxSizeEvent &evt) 
+void COScopeCtrl::OnSize(wxSizeEvent &evt)
 {
     int iTrend;
     //CWnd::OnSize(nType, cx, cy) ;
 #if 0
     if (!theApp.xmuledlg)
     return;
-    if (!theApp.xmuledlg -> IsRunning())
+    if (!theApp.xmuledlg->IsRunning())
     return;
 #endif
-    if (oldwidth == evt.GetSize() .GetWidth() &&oldheight == evt.GetSize() .GetHeight()) 
+    if (oldwidth == evt.GetSize() .GetWidth() &&oldheight == evt.GetSize() .GetHeight())
     {
         // same size. don't touch
         return;
@@ -910,22 +909,22 @@ void COScopeCtrl:: OnSize(wxSizeEvent &evt)
     m_nPlotWidth = m_rectPlot.right - m_rectPlot.left;
     // set the scaling factor for now, this can be adjusted
     // in the SetRange functions
-    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+    for (iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
     {
         m_PlotData[ iTrend ].dVerticalFactor = (double) m_nPlotHeight / m_PlotData[ iTrend ].dRange;
     }
     // destroy grid dc and bitmap (Invalidate recreates it)
-    if (m_dcGrid) 
+    if (m_dcGrid)
     {
-        m_dcGrid -> SelectObject(wxNullBitmap);
+        m_dcGrid->SelectObject(wxNullBitmap);
         if (m_bitmapGrid) delete m_bitmapGrid;
         delete m_dcGrid;
         m_bitmapGrid = NULL;
         m_dcGrid = NULL;
     }
-    if (m_dcPlot) 
+    if (m_dcPlot)
     {
-        m_dcPlot -> SelectObject(wxNullBitmap);
+        m_dcPlot->SelectObject(wxNullBitmap);
         if (m_bitmapPlot) delete m_bitmapPlot;
         delete m_dcPlot;
         m_bitmapPlot = NULL;
@@ -934,7 +933,7 @@ void COScopeCtrl:: OnSize(wxSizeEvent &evt)
 #if 0
     // destroy and recreate the grid bitmap
     CClientDC dc(this);
-    if (m_pbitmapOldGrid &&m_bitmapGrid.GetSafeHandle() &&m_dcGrid.GetSafeHdc()) 
+    if (m_pbitmapOldGrid &&m_bitmapGrid.GetSafeHandle() &&m_dcGrid.GetSafeHdc())
     {
         m_dcGrid.SelectObject(m_pbitmapOldGrid);
         m_bitmapGrid.DeleteObject();
@@ -942,7 +941,7 @@ void COScopeCtrl:: OnSize(wxSizeEvent &evt)
         m_pbitmapOldGrid = m_dcGrid.SelectObject( &m_bitmapGrid);
     }
     // destroy and recreate the plot bitmap
-    if (m_pbitmapOldPlot &&m_bitmapPlot.GetSafeHandle() &&m_dcPlot.GetSafeHdc()) 
+    if (m_pbitmapOldPlot &&m_bitmapPlot.GetSafeHandle() &&m_dcPlot.GetSafeHdc())
     {
         m_dcPlot.SelectObject(m_pbitmapOldPlot);
         m_bitmapPlot.DeleteObject();
@@ -958,26 +957,26 @@ void COScopeCtrl:: OnSize(wxSizeEvent &evt)
 }
 
 /////////////////////////////////////////////////////////////////////////////
-void COScopeCtrl:: Reset() 
+void COScopeCtrl::Reset()
 {
     // to clear the existing data (in the form of a bitmap)
     // simply invalidate the entire control
     InvalidateCtrl();
 }
 
-int COScopeCtrl:: ReCreateGraph(void) 
+int COScopeCtrl::ReCreateGraph(void)
 {
     int i;
-    for (i = 0 ; i < m_NTrends ; i++) 
+    for (i = 0 ; i < m_NTrends ; i++)
     {
         m_PlotData[i].dPreviousPosition = 0.0;
         m_PlotData[i].nPrevY = - 1;
     }
     double *pAddPoints = new double[m_NTrends];
     int iCnt = m_PlotData[0].lstPoints.GetCount();
-    for (int i = 0 ; i < iCnt ; i++) 
+    for (int i = 0 ; i < iCnt ; i++)
     {
-        for (int iTrend = 0 ; iTrend < m_NTrends ; iTrend++) 
+        for (int iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
         {
 #if 0
             m_PlotData[iTrend].nPrevY = - 1;
@@ -996,22 +995,22 @@ int COScopeCtrl:: ReCreateGraph(void)
 }
 
 //void COScopeCtrl::OnTimer(UINT nIDEvent)
-void COScopeCtrl:: OnTimer(wxTimerEvent &evt) 
+void COScopeCtrl::OnTimer(wxTimerEvent &evt)
 {
-    if (!theApp.xmuledlg -> IsRunning())
+    if (!theApp.xmuledlg->IsRunning())
     return;
     m_nRedrawTimer.Stop();
     m_bDoUpdate = true;
     ReCreateGraph();
 #if 0
-    if (nIDEvent == m_nRedrawTimer) 
+    if (nIDEvent == m_nRedrawTimer)
     {
         KillTimer(m_nRedrawTimer);
         m_nRedrawTimer = 0;
         m_bDoUpdate = true;
         ReCreateGraph();
     }
-    CWnd:: OnTimer(nIDEvent);
+    CWnd::OnTimer(nIDEvent);
 #endif
 }
 
