@@ -1,42 +1,66 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright(C)2002 Tiku & Patrizio Bassi aka Hetfield <hetfield@email.it>
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
 //
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
 //
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-#ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "Preferences.h"
-#	include "SharedFileList.h"
-#	include "SysTray.h"
-#	include "UploadQueue.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#endif
-
-#include <libintl.h>
-#include "pixmaps/mule_Tr_grey.ico.xpm"
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef __SYSTRAY_DISABLED__
 
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
+
+#include "SysTray.h"                        // Needed for this Interface's Prototype
+
+#include "config.h"                         // Needed for VERSION
+#include "eggtrayicon.h"                    // Needed for egg_tray_icon_new
+#include "NewFunctions.h"                   // Needed for MAP
+#include "opcodes.h"                        // Needed for UNLIMITED
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // CPreferences::GetUserHash
+#include "resource.h"                       // Needed for IDS_CONNECTING
+#include "server.h"                         // Needed for CServer
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <arpa/inet.h>                      // Needed for inet_ntoa
+#include <gtk/gtk.h>                        // Needed for gtk_menu_new
+#include <libintl.h>                        // Needed for bindtextdomain
+#include <net/if.h>                         // Needed for ifreq
+#include <netinet/in.h>                     // Needed for sockaddr_in
+#include <sys/ioctl.h>                      // Needed for SIOCGIFADDR
+#include <X11/Xatom.h>                      // Needed for XA_WINDOW
+#include <deque>                            // Needed for std::deque
+
+#ifdef __WXMAC__
+    #include <sys/types.h>
+    #include <sys/socket.h>
+#endif
+
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+
+#include "pixmaps/mule_Tr_grey.ico.xpm"
+
 #ifdef __SAFE_TRAY__
-gchar *getIP() 
+gchar *getIP()
 {
     gchar *ip = "Detection Disabled";
     return ip;
@@ -44,8 +68,11 @@ gchar *getIP()
 
 #endif
 
+std::deque<int> m_pLimits;
+std::deque<COLORREF> m_pColors;
+
 #ifndef __SAFE_TRAY__
-gchar *getIP() 
+gchar *getIP()
 {
     gchar *ip = "Not Found";
     wxString interface;
@@ -57,26 +84,26 @@ gchar *getIP()
     memset( &ifr, 0, sizeof ifr);
     sfd = socket(AF_INET, SOCK_STREAM, 0);
     strcpy(ifr.ifr_name, "ppp0");
-    sin -> sin_family = AF_INET;
-    if (0 == ioctl(sfd, SIOCGIFADDR, &ifr)) 
+    sin->sin_family = AF_INET;
+    if (0 == ioctl(sfd, SIOCGIFADDR, &ifr))
     {
-        ip = inet_ntoa(sin -> sin_addr);
+        ip = inet_ntoa(sin->sin_addr);
         return ip;
     }
-    else 
+    else
     {
         printf("Not connected at network with ppp0 direct connection\n");
-        do 
+        do
         {
-            interface = "eth" + wxString:: Format("%d", index);
+            interface = "eth" + wxString::Format("%d", index);
             strcpy(ifr.ifr_name, interface);
-            sin -> sin_family = AF_INET;
-            if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0) 
+            sin->sin_family = AF_INET;
+            if (ioctl(sfd, SIOCGIFADDR, &ifr) == 0)
             {
-                ip = inet_ntoa(sin -> sin_addr);
+                ip = inet_ntoa(sin->sin_addr);
                 index++;
             }
-            else 
+            else
             {
                 printf(wxString("Not connected at network with ") + interface);
             }
@@ -87,136 +114,149 @@ gchar *getIP()
 }
 
 #endif
-
+#include <iostream>
+using namespace std;
 // Same check of the connection tab.
-void speed_check() 
+void speed_check()
 {
-    if (theApp.glob_prefs -> GetMaxGraphDownloadRate() < theApp.glob_prefs -> GetMaxDownload())
-    theApp.glob_prefs -> SetDownloadlimit(UNLIMITED);
-    if (theApp.glob_prefs -> GetMaxGraphUploadRate() < theApp.glob_prefs -> GetMaxUpload())
-    theApp.glob_prefs -> SetUploadlimit(UNLIMITED);
-    if (theApp.glob_prefs -> GetMaxUpload() != UNLIMITED) 
+    if (theApp.dynprefs->Get<long>("capacities-download") < theApp.dynprefs->Get<long>("limits-download"))
     {
-        if (theApp.glob_prefs -> GetMaxUpload() < 4 && (theApp.glob_prefs -> GetMaxUpload() *3 < theApp.glob_prefs -> GetMaxDownload()))
-        theApp.glob_prefs -> SetDownloadlimit((theApp.glob_prefs -> GetMaxUpload() *3));
-        if (theApp.glob_prefs -> GetMaxUpload() < 10 && (theApp.glob_prefs -> GetMaxUpload() *4 < theApp.glob_prefs -> GetMaxDownload()))
-        theApp.glob_prefs -> SetDownloadlimit((theApp.glob_prefs -> GetMaxUpload() *4));
+        theApp.dynprefs->Add("limits-download", UNLIMITED);
+    }
+
+    if (theApp.dynprefs->Get<long>("capacities-upload") < theApp.dynprefs->Get<long>("limits-upload"))
+    {
+        theApp.dynprefs->Add("limits-upload", UNLIMITED);
+    }
+
+    long int max_upload = theApp.dynprefs->Get<long>("limits-upload");
+    if (max_upload != UNLIMITED)
+    {
+        cout << "Unlimited: " << UNLIMITED << " | limits-upload: " << max_upload << endl;
+        if ((max_upload < 4) && (max_upload * 3 < theApp.dynprefs->Get<long>("limits-download")))
+        {
+            theApp.dynprefs->Add("limits-download", max_upload * 3);
+        }
+        else if ((max_upload < 10) && (max_upload * 4 < theApp.dynprefs->Get<long>("limits-download")))
+        {
+            theApp.dynprefs->Add("limits-download", max_upload * 4);
+        }
     }
 }
 
 // Closes xMule
-void close_xmule() 
+void close_xmule()
 {
     wxCloseEvent SendCloseEvent;
-    theApp.xmuledlg -> OnClose(SendCloseEvent);
+    theApp.xmuledlg->OnClose(SendCloseEvent);
 }
 
 // Hides xMule
-void hide_xmule() 
+void hide_xmule()
 {
-    if (theApp.xmuledlg -> IsShown()) 
+    if (theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Show(FALSE);
+        theApp.xmuledlg->Show(FALSE);
     }
 }
 
 // Shows xMule
-void show_xmule() 
+void show_xmule()
 {
-    if (!theApp.xmuledlg -> IsShown()) 
+    if (!theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Show(TRUE);
+        theApp.xmuledlg->Show(TRUE);
     }
 }
 
 // Shows or hides xMule...double click automatic selection
-void showgui() 
+void showgui()
 {
-    if (theApp.xmuledlg -> IsShown()) 
+    if (theApp.xmuledlg->IsShown())
     {
-        theApp.xmuledlg -> Iconize(TRUE);
-        theApp.xmuledlg -> Show(FALSE);
+        theApp.xmuledlg->Iconize(TRUE);
+        theApp.xmuledlg->Show(FALSE);
     }
-    else 
+    else
     {
-        theApp.xmuledlg -> Show(TRUE);
+        theApp.xmuledlg->Show(TRUE);
     }
 }
 
 // Set download and upload speed to max
-void set_all_max() 
+void set_all_max()
 {
-    theApp.glob_prefs -> SetUploadlimit(theApp.glob_prefs -> GetMaxGraphUploadRate());
-    theApp.glob_prefs -> SetDownloadlimit(theApp.glob_prefs -> GetMaxGraphDownloadRate());
+    theApp.dynprefs->Add("limits-upload", theApp.dynprefs->Get<long>("capacities-upload"));
+    theApp.dynprefs->Add("limits-download", theApp.dynprefs->Get<long>("capacities-download"));
 }
 
 // Set download and upload speed to min
-void set_all_min() 
+void set_all_min()
 {
-    theApp.glob_prefs -> SetUploadlimit(2);
-    theApp.glob_prefs -> SetDownloadlimit(2);
+    theApp.dynprefs->Add("limits-download", 2L);
+    theApp.dynprefs->Add("limits-upload", 2L);
     speed_check();
 }
 
 // Connect to a server
-void connect_any_server() 
+void connect_any_server()
 {
-    if (theApp.serverconnect -> IsConnected()) 
+    if (theApp.serverconnect->IsConnected())
     {
-        theApp.serverconnect -> Disconnect();
+        theApp.serverconnect->Disconnect();
     }
-    theApp.xmuledlg -> AddLogLine(true, GetResString(IDS_CONNECTING));
-    theApp.serverconnect -> ConnectToAnyServer();
-    theApp.xmuledlg -> ShowConnectionState(false);
+    theApp.xmuledlg->AddLogLine(true, GetResString(IDS_CONNECTING));
+    theApp.serverconnect->ConnectToAnyServer();
+    theApp.xmuledlg->ShowConnectionState(false);
 }
 
 // Disconnect
-void disconnect() 
+void disconnect()
 {
-    if (theApp.serverconnect -> IsConnected()) 
+    if (theApp.serverconnect->IsConnected())
     {
-        theApp.serverconnect -> Disconnect();
+        theApp.serverconnect->Disconnect();
     }
-    else 
+    else
     {
         printf("Already disconnected!\n");
     }
 }
 
 // Set download speed
-void set_dl_speed(GtkWidget *widget, GdkEventButton *event, gpointer data) 
+void set_dl_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    int temp;
-    temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
-    if (temp == 0) 
+    long temp;
+    temp = atol(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
+    if (temp == 0)
     {
-        theApp.glob_prefs -> SetDownloadlimit(UNLIMITED);
+        theApp.dynprefs->Add("limits-download", UNLIMITED);
     }
-    else 
+    else
     {
-        theApp.glob_prefs -> SetDownloadlimit(temp);
+        theApp.dynprefs->Add("limits-download", temp);
     }
     speed_check();
 }
 
 // Set upload speed
-void set_up_speed(GtkWidget *widget, GdkEventButton *event, gpointer data) 
+void set_up_speed(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    int temp;
-    temp = atoi(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
-    if (temp == 0) 
+    long temp;
+    temp = atol(g_strdup_printf("%s", gtk_object_get_data(GTK_OBJECT(widget), "label")));
+    if (temp == 0)
     {
-        theApp.glob_prefs -> SetUploadlimit(UNLIMITED);
+        theApp.dynprefs->Add("limits-upload", UNLIMITED);
     }
-    else 
+    else
     {
-        theApp.glob_prefs -> SetUploadlimit(temp);
+        theApp.dynprefs->Add("limits-upload", temp);
     }
     speed_check();
 }
 
 // Create menu linked to the tray icon
-static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer data) 
+static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
     // Sets gtk objects
     GtkWidget *status_menu, *item, *down_speed, *dl_item, *up_speed, *up_item, *info_menu, *info_item;
@@ -227,66 +267,67 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     uint16 max_dl_speed, max_up_speed;
     uint16 actual_dl_speed, actual_up_speed;
     speed_check();
-    actual_up_speed = theApp.glob_prefs -> GetMaxUpload();
-    actual_dl_speed = theApp.glob_prefs -> GetMaxDownload();
-    max_up_speed = theApp.glob_prefs -> GetMaxGraphUploadRate();
-    max_dl_speed = theApp.glob_prefs -> GetMaxGraphDownloadRate();
+    actual_up_speed = theApp.dynprefs->Get<long>("limits-upload");
+    actual_dl_speed = theApp.dynprefs->Get<long>("limits-download");
+    max_up_speed = theApp.dynprefs->Get<long>("capacities-upload");
+    max_dl_speed = theApp.dynprefs->Get<long>("capacities-download");
     // What will be shown, very nice!
-    if (actual_dl_speed == UNLIMITED || actual_dl_speed == 0) 
+    if (actual_dl_speed == UNLIMITED || actual_dl_speed == 0)
     {
         dl_speed = "Unlimited";
     }
-    else 
+    else
     {
         temp = g_strdup_printf("%d", actual_dl_speed);
         dl_speed = temp;
     }
-    if (actual_up_speed == UNLIMITED || actual_up_speed == 0) 
+    if (actual_up_speed == UNLIMITED || actual_up_speed == 0)
     {
         upl_speed = "Unlimited";
     }
-    else 
+    else
     {
         temp = g_strdup_printf("%d", actual_up_speed);
         upl_speed = temp;
     }
-    if (max_dl_speed == UNLIMITED || max_dl_speed == 0) 
+    if (max_dl_speed == UNLIMITED || max_dl_speed == 0)
     {
         max_dl_speed = 100;
     }
-    if (max_up_speed == UNLIMITED || max_up_speed == 0) 
+    if (max_up_speed == UNLIMITED || max_up_speed == 0)
     {
         max_up_speed = 100;
     }
-    label = "xMule " + wxString(VERSION) + "\nActual Speed Limits:\nDL: " + dl_speed + " kb/s " + "UP:" + upl_speed + " kb/s";
+    label = "xMule " + wxString(PACKAGE_VERSION) + "\nActual Speed Limits:\nDL: " + dl_speed + " kb/s " + "UP:" + upl_speed + " kb/s";
     // Info menu
     info_menu = gtk_menu_new();
     gtk_menu_set_title(GTK_MENU(info_menu), "xMule TrayMenu Info");
-    if (theApp.glob_prefs -> GetUserNick() != NULL) 
+
+    if (theApp.dynprefs->Get<wxString>("nickname").IsEmpty() != true)
     {
-        info_item = gtk_menu_item_new_with_label(wxString("Nick: ") + theApp.glob_prefs -> GetUserNick());
+        info_item = gtk_menu_item_new_with_label(wxT("Nick: ") + theApp.dynprefs->Get<wxString>("nickname"));
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("Nick: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetUserHash()) 
+    if (theApp.glob_prefs->GetUserHash())
     {
         CString hash;
-        hash = EncodeBase16((const unsigned char *) theApp.glob_prefs -> GetUserHash(), 16);
+        hash = EncodeBase16((const unsigned char *) theApp.glob_prefs->GetUserHash(), 16);
         info_item = gtk_menu_item_new_with_label(wxString("Hash: ") + hash.GetBuffer());
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("Hash: Not Ready");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.serverconnect -> IsConnected()) 
+    if (theApp.serverconnect->IsConnected())
     {
-        info_item = gtk_menu_item_new_with_label(wxString("ClientID: ") + wxString:: Format("%.0f", (float) theApp.serverconnect -> GetClientID()));
+        info_item = gtk_menu_item_new_with_label(wxString("ClientID: ") + wxString::Format("%.0f", (float) theApp.serverconnect->GetClientID()));
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("ID: Not Connected");
     }
@@ -294,72 +335,70 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     tempstring = getIP();
     info_item = gtk_menu_item_new_with_label(wxString("IP: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetPort()) 
-    {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs -> GetPort());
-        info_item = gtk_menu_item_new_with_label(wxString("TCP Port: ") + tempstring);
-    }
-    else 
-    {
-        info_item = gtk_menu_item_new_with_label("TCP Port: Not Ready");
-    }
+
+    tempstring = g_strdup_printf("%d", theApp.dynprefs->Get<long>("tcp-port"));
+    info_item = gtk_menu_item_new_with_label(wxString("TCP Port: ") + tempstring);
+
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> GetUDPPort()) 
+
+    long udp_port(theApp.dynprefs->Get<long>("udp-port"));
+    if (udp_port)
     {
-        tempstring = g_strdup_printf("%d", theApp.glob_prefs -> GetUDPPort());
+        tempstring = g_strdup_printf("%d", udp_port);
         info_item = gtk_menu_item_new_with_label(wxString("UDP Port: ") + tempstring);
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("UDP Port: Not Ready");
     }
+
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.glob_prefs -> IsOnlineSignatureEnabled()) 
+    if (theApp.dynprefs->Get<bool>("online-signature") == true)
     {
         info_item = gtk_menu_item_new_with_label("Online Signature: Enabled");
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("Online Signature: Disabled");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.Start_time > 0) 
+    if (theApp.Start_time > 0)
     {
         DWORD running;
         running = (GetTickCount() - theApp.Start_time) / 1000;
         tempstring = g_strdup_printf("%s", CastSecondsToHM(running) .GetData());
         info_item = gtk_menu_item_new_with_label(wxString("Uptime: ") + tempstring);
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("Uptime: None");
     }
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    if (theApp.serverconnect -> GetCurrentServer() != NULL) 
+    if (theApp.serverconnect->GetCurrentServer() != NULL)
     {
-        info_item = gtk_menu_item_new_with_label(wxString("ServerName: ") + theApp.serverconnect -> GetCurrentServer() -> GetListName());
+        info_item = gtk_menu_item_new_with_label(wxString("ServerName: ") + theApp.serverconnect->GetCurrentServer()->GetListName());
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-        tempstring = g_strdup_printf("%d", theApp.serverconnect -> GetCurrentServer() -> GetPort());
-        info_item = gtk_menu_item_new_with_label(wxString("ServerIP: ") + theApp.serverconnect -> GetCurrentServer() -> GetFullIP() + wxString(" : ") + tempstring);
+        tempstring = g_strdup_printf("%d", theApp.serverconnect->GetCurrentServer()->GetPort());
+        info_item = gtk_menu_item_new_with_label(wxString("ServerIP: ") + theApp.serverconnect->GetCurrentServer()->GetFullIP() + wxString(" : ") + tempstring);
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     }
-    else 
+    else
     {
         info_item = gtk_menu_item_new_with_label("ServerName: Not Connected");
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
         info_item = gtk_menu_item_new_with_label("ServerIP: Not Connected");
         gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     }
-    tempstring = g_strdup_printf("%d", theApp.sharedfiles -> GetCount());
+//    tempstring = g_strdup_printf("%d", theApp.sharedfiles->listof_SharedFiles->Data);
     info_item = gtk_menu_item_new_with_label(wxString("Shared Files: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%d", theApp.uploadqueue -> GetWaitingUserCount());
+    tempstring = g_strdup_printf("%d", theApp.uploadqueue->GetWaitingUserCount());
     info_item = gtk_menu_item_new_with_label(wxString("Queued Clients: ") + tempstring);
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionReceivedBytes + theApp.glob_prefs -> GetTotalDownloaded()) / 1073741824));
+    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded()) / 1073741824));
     info_item = gtk_menu_item_new_with_label(wxString("Total DL: ") + tempstring + wxString("  GB"));
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
-    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionSentBytes + theApp.glob_prefs -> GetTotalUploaded()) / 1073741824));
+    tempstring = g_strdup_printf("%.2f", ((float)(theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded()) / 1073741824));
     info_item = gtk_menu_item_new_with_label(wxString("Total UP: ") + tempstring + wxString("  GB"));
     gtk_container_add(GTK_CONTAINER(info_menu), info_item);
     // Main menu
@@ -517,20 +556,20 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     // gtk_signal_connect(GTK_OBJECT(info_menu), "leave_notify_event", GTK_SIGNAL_FUNC(gtk_widget_destroy), &info_menu);
     // Finalization
     gtk_widget_show_all(status_menu);
-    gtk_menu_popup(GTK_MENU(status_menu), NULL, NULL, NULL, NULL, event -> button, event -> time);
+    gtk_menu_popup(GTK_MENU(status_menu), NULL, NULL, NULL, NULL, event->button, event->time);
     return TRUE;
 }
 
-static gboolean tray_clicked(GtkWidget *event_box, GdkEventButton *event, gpointer data) 
+static gboolean tray_clicked(GtkWidget *event_box, GdkEventButton *event, gpointer data)
 {
     // Mouse wheel or middle click + left double click
-    if ((event -> button == 1 &&event -> type == GDK_2BUTTON_PRESS) || event -> button == 2) 
+    if ((event->button == 1 &&event->type == GDK_2BUTTON_PRESS) || event->button == 2)
     {
         showgui();
         return true;
     }
     // Mouse right click
-    if (event -> button == 3) 
+    if (event->button == 3)
     {
         return tray_menu(event_box, event, data);
     }
@@ -538,7 +577,7 @@ static gboolean tray_clicked(GtkWidget *event_box, GdkEventButton *event, gpoint
 
 #endif
 
-CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title) 
+CSysTray::CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
 {
 #ifndef __SYSTRAY_DISABLED__
     static GtkWidget *eventbox;
@@ -548,35 +587,33 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     m_nSpacingWidth = 1;
     m_nNumBars = 1;
     m_nMaxVal = 100;
-    m_pLimits = NULL;
-    m_pColors = NULL;
     parent = _parent;
     desktopMode = _desktopMode;
-    if (desktopMode == 4) 
+    if (desktopMode == 3)
     {
         // Not wanted, so don't show it.
         return;
     }
     setlocale(LC_ALL, "");
-    bindtextdomain(PACKAGE, LOCALEDIR);
-    textdomain(PACKAGE);
+    bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+    textdomain(PACKAGE_NAME);
     bool use_legacy = false;
     // Case 2 and 3 are KDE/other legacy system
-    if (desktopMode == 2 || desktopMode == 3) 
+    if (desktopMode == 1 || desktopMode == 2)
     {
         use_legacy = true;
     }
-    if (use_legacy) 
+    if (use_legacy)
     {
         status_docklet = gtk_window_new(GTK_WINDOW_TOPLEVEL);
         gtk_window_set_title(GTK_WINDOW(status_docklet), title);
         gtk_window_set_wmclass(GTK_WINDOW(status_docklet), "xmule_StatusDocklet", "xMule");
         gtk_widget_set_usize(status_docklet, 22, 22);
     }
-    else 
+    else
     {
         status_docklet = GTK_WIDGET(egg_tray_icon_new(_("xMule for Linux")));
-        if (status_docklet == NULL) 
+        if (status_docklet == NULL)
         {
             printf("**** WARNING: Can't create status docklet. Systray will not be created.\n");
             desktopMode = 4;
@@ -588,7 +625,7 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     // Set image
     GdkBitmap *mask = NULL;
     GdkPixmap *
-    img = gdk_pixmap_create_from_xpm_d(status_docklet -> window, &mask, NULL, mule_Tr_grey_ico);
+    img = gdk_pixmap_create_from_xpm_d(status_docklet->window, &mask, NULL, mule_Tr_grey_ico);
     status_image = gtk_pixmap_new(img, mask);
     eventbox = gtk_event_box_new();
     gtk_widget_show(eventbox);
@@ -602,7 +639,7 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
     gtk_tooltips_set_tip(status_tooltips, status_docklet, _("xMule for Linux"), "blind text");
     // Finalization
     gtk_widget_show(status_image);
-    if (use_legacy) 
+    if (use_legacy)
     {
         setupProperties();
     }
@@ -611,10 +648,10 @@ CSysTray:: CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
 #endif
 }
 
-void CSysTray:: setupProperties() 
+void CSysTray::setupProperties()
 {
 #ifndef __SYSTRAY_DISABLED__
-    GdkWindow *window = status_docklet -> window;
+    GdkWindow *window = status_docklet->window;
     glong data[1];
     GdkAtom kwm_dockwindow_atom;
     GdkAtom kde_net_system_tray_window_for_atom;
@@ -630,14 +667,14 @@ void CSysTray:: setupProperties()
 #endif
 }
 
-void CSysTray:: Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DWORD dwTimeToStay, DWORD dwTimeTOHide) 
+void CSysTray::Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DWORD dwTimeToStay, DWORD dwTimeTOHide)
 {
 #ifndef __SYSTRAY_DISABLED__
-    if (desktopMode == 4) 
+    if (desktopMode == 4)
     {
         return;
     }
-    if (status_docklet == NULL) 
+    if (status_docklet == NULL)
     {
         return;
     }
@@ -645,14 +682,14 @@ void CSysTray:: Show(const wxChar *caption, int nMsgType, DWORD dwTimeToShow, DW
 #endif
 }
 
-void CSysTray:: TraySetToolTip(char *data) 
+void CSysTray::TraySetToolTip(char *data)
 {
 #ifndef __SYSTRAY_DISABLED__
-    if (desktopMode == 4) 
+    if (desktopMode == 4)
     {
         return;
     }
-    if (status_docklet == NULL) 
+    if (status_docklet == NULL)
     {
         return;
     }
@@ -661,12 +698,12 @@ void CSysTray:: TraySetToolTip(char *data)
 }
 
 // It the nLevel is greater than the values defined in m_pLimits the last value in the array is used
-COLORREF CSysTray:: GetMeterColor(int nLevel) 
+COLORREF CSysTray::GetMeterColor(int nLevel)
 {
 #ifndef __SYSTRAY_DISABLED__
-    for (int i = 0 ; i < m_nEntries ; i++) 
+    for (int i = 0 ; i < m_nEntries ; i++)
     {
-        if (nLevel <= m_pLimits[i]) 
+        if (nLevel <= m_pLimits[i])
         {
             return m_pColors[i];
         }
@@ -677,7 +714,7 @@ COLORREF CSysTray:: GetMeterColor(int nLevel)
     return m_pColors[m_nEntries - 1];
 }
 
-void CSysTray:: DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int nPos) 
+void CSysTray::DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int nPos)
 {
 #ifndef __SYSTRAY_DISABLED__
     GdkGC *gc = gdk_gc_new(pix);
@@ -689,7 +726,7 @@ void CSysTray:: DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int n
     GdkGC *newgc = gdk_gc_new(mask);
     gdk_rgb_gc_set_foreground(newgc, 0x0);
     gdk_draw_rectangle(mask, newgc, TRUE, 0, 0, 22, 22);
-    if (nLevel > 0) 
+    if (nLevel > 0)
     {
         gdk_rgb_gc_set_foreground(newgc, 0xffffff);
         gdk_draw_rectangle(mask, newgc, 1, m_sDimensions.cx - 2, m_sDimensions.cy - ((nLevel * (m_sDimensions.cy - 1) / m_nMaxVal) + 1), m_sDimensions.cx, m_sDimensions.cy);
@@ -699,28 +736,28 @@ void CSysTray:: DrawIconMeter(GdkPixmap *pix, GdkBitmap *mask, int nLevel, int n
 #endif
 }
 
-void CSysTray:: drawMeters(GdkPixmap *pix, GdkBitmap *mask, int *pBarData) 
+void CSysTray::drawMeters(GdkPixmap *pix, GdkBitmap *mask, int *pBarData)
 {
 #ifndef __SYSTRAY_DISABLED__
-    if (pBarData == NULL) 
+    if (pBarData == NULL)
     {
         return;
     }
-    for (int i = 0 ; i < m_nNumBars ; i++) 
+    for (int i = 0 ; i < m_nNumBars ; i++)
     {
         DrawIconMeter(pix, mask, pBarData[i], i);
     }
 #endif
 }
 
-void CSysTray:: TraySetIcon(char **data, bool what, int *pVals) 
+void CSysTray::TraySetIcon(char **data, bool what, int *pVals)
 {
 #ifndef __SYSTRAY_DISABLED__
-    if (desktopMode == 4) 
+    if (desktopMode == 4)
     {
         return;
     }
-    if (status_image == NULL) 
+    if (status_image == NULL)
     {
         // There is nothing you can do..:
         return;
@@ -729,10 +766,10 @@ void CSysTray:: TraySetIcon(char **data, bool what, int *pVals)
     GdkPixmap *newpix, *newbit;
     /* Set new picture */
     gtk_pixmap_get(GTK_PIXMAP(status_image), &oldpix, &oldbit);
-    newpix = gdk_pixmap_create_from_xpm_d(status_docklet -> window, &newbit, NULL, data);
+    newpix = gdk_pixmap_create_from_xpm_d(status_docklet->window, &newbit, NULL, data);
     /* Create pixmap for meters */
-    GdkPixmap *meterpix = gdk_pixmap_new(status_docklet -> window, 22, 22, - 1);
-    GdkBitmap *meterbit = gdk_pixmap_new(status_docklet -> window, 22, 22, 1);
+    GdkPixmap *meterpix = gdk_pixmap_new(status_docklet->window, 22, 22, - 1);
+    GdkBitmap *meterbit = gdk_pixmap_new(status_docklet->window, 22, 22, 1);
     /* Draw meters */
     drawMeters(meterpix, meterbit, pVals);
     /* Then draw meters onto main pix */
@@ -757,23 +794,10 @@ void CSysTray:: TraySetIcon(char **data, bool what, int *pVals)
 #endif
 }
 
-bool CSysTray:: SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries) 
+bool CSysTray::SetColorLevels(int *pLimits, COLORREF *pColors, int nEntries)
 {
 #ifndef __SYSTRAY_DISABLED__
-    // Free allocated memory
-    if (m_pLimits) 
-    {
-        delete[] m_pLimits;
-    }
-    if (m_pColors) 
-    {
-        delete[] m_pColors;
-    }
-    // Allocate new memory
-    m_pLimits = new int[nEntries];
-    m_pColors = new COLORREF[nEntries];
-    // Copy values
-    for (int i = 0 ; i < nEntries ; i++) 
+    for (int i = 0 ; i < nEntries ; i++)
     {
         m_pLimits[i] = pLimits[i];
         m_pColors[i] = pColors[i];
