@@ -1,29 +1,31 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
-//
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
 #	include "ClientUDPSocket.h"
 #	include "KnownFile.h"
+#include "ListenSocket.h"                   // CClientReqSocket
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
 #	include "opcodes.h"
 #	include "otherfunctions.h"
 #	include "otherstructs.h"
@@ -38,14 +40,16 @@
 #	include "NewSockets.h"
 #endif
 
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+
 #include <zlib.h>
 
 //	members of CUpDownClient
 //	which are mainly used for uploading functions
 
-CBarShader CUpDownClient:: s_UpStatusBar(16);
+CBarShader CUpDownClient::s_UpStatusBar(16);
 
-void CUpDownClient:: DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
     RECT gaprect;
     gaprect.top = rect.y + 2;
@@ -56,15 +60,15 @@ void CUpDownClient:: DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyr
     gaprect.right = (rect.x + rect.width);
     //dc->FillRect(&gaprect,&CBrush(RGB(220,220,220)));
     wxBrush suti(wxColour(220, 220, 220), wxSOLID);
-    dc -> SetPen( *wxTRANSPARENT_PEN);
-    dc -> SetBrush(suti);
+    dc->SetPen( *wxTRANSPARENT_PEN);
+    dc->SetBrush(suti);
     wxRect mygaprect;
     mygaprect.x = gaprect.left;
     mygaprect.y = gaprect.top;
     mygaprect.width = gaprect.right - gaprect.left;
     mygaprect.height = gaprect.bottom - gaprect.top;
-    dc -> DrawRectangle(mygaprect);
-    dc -> SetBrush( *wxWHITE_BRUSH);
+    dc->DrawRectangle(mygaprect);
+    dc->SetBrush( *wxWHITE_BRUSH);
     if (onlygreyrect)
     {
         return;
@@ -77,12 +81,12 @@ void CUpDownClient:: DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyr
             gaprect.right = rect.x + (uint32)(((float) PARTSIZE *i/1024) *blockpixel);
             gaprect.left = rect.x + (uint32)((float)((float) PARTSIZE * (i + 1) /1024) *blockpixel);
             //dc->FillRect(&gaprect,&CBrush(RGB(0,0,0)));
-            dc -> SetBrush( *wxBLACK_BRUSH);
+            dc->SetBrush( *wxBLACK_BRUSH);
             mygaprect.x = gaprect.left;
             mygaprect.y = gaprect.top;
             mygaprect.width = gaprect.right - gaprect.left;
             mygaprect.height = gaprect.bottom - gaprect.top;
-            dc -> DrawRectangle(mygaprect);
+            dc->DrawRectangle(mygaprect);
         }
     }
 }
@@ -121,7 +125,7 @@ void CUpDownClient:: DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyr
  }
     */
 
-uint32 CUpDownClient:: GetScore(bool sysvalue, bool isdownloading, bool onlybasevalue)
+uint32 CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasevalue)
 {
     //TODO: complete this (friends, uploadspeed, xmuleuser etc etc)
     if (!m_pszUsername)
@@ -131,7 +135,7 @@ uint32 CUpDownClient:: GetScore(bool sysvalue, bool isdownloading, bool onlybase
     return 0x0FFFFFFF;
     if (IsBanned())
     return 0;
-    if (sysvalue &&HasLowID() && ! (socket &&socket -> IsConnected()))
+    if (sysvalue &&HasLowID() && ! (socket &&socket->IsConnected()))
     {
         return 0;
     }
@@ -141,13 +145,13 @@ uint32 CUpDownClient:: GetScore(bool sysvalue, bool isdownloading, bool onlybase
     // high prio file, but then asks for something completely different.
     // standard:
     int filepriority = 10;
-    CKnownFile *pFile = theApp.sharedfiles -> GetFileByID(GetUploadFileID());
+    CKnownFile *pFile = theApp.sharedfiles->GetFileByID(GetUploadFileID());
     if (pFile != NULL)
     {
-        switch (pFile -> GetUpPriority())
+        switch (pFile->GetUpPriority())
         {
         case PR_VERYHIGH:
-            if (pFile -> IsAutoUpPriority())
+            if (pFile->IsAutoUpPriority())
             {
                 filepriority = 35;
             }
@@ -176,24 +180,24 @@ uint32 CUpDownClient:: GetScore(bool sysvalue, bool isdownloading, bool onlybase
     if (onlybasevalue)
     fBaseValue = 100;
     else if(!isdownloading)
-    fBaseValue = (float)(:: GetTickCount() - m_dwWaitTime) /1000;
+    fBaseValue = (float)(::GetTickCount() - m_dwWaitTime) /1000;
     else
     {
         // we dont want one client to download forever
         // the first 15 min downloadtime counts as 15 min waitingtime and you get a 15 min bonus while you are in the first 15 min :)
         // (to avoid 20 sec downloads) after this the score won't raise anymore
         fBaseValue = (float)(m_dwUploadTime - m_dwWaitTime);
-        fBaseValue += (float)(:: GetTickCount() - m_dwUploadTime > 900000) ? 900000: 1800000;
+        fBaseValue += (float)(::GetTickCount() - m_dwUploadTime > 900000) ? 900000: 1800000;
         fBaseValue /= 1000;
     }
-    fBaseValue *= credits -> GetScoreRatio();
+    fBaseValue *= credits->GetScoreRatio(GetIP());
     if (!onlybasevalue)
     fBaseValue *= (float(filepriority) /10.0f);
     if (!isdownloading && !onlybasevalue)
     {
-        if (HasLowID() && ! (socket &&socket -> IsConnected()))
+        if (HasLowID() && ! (socket &&socket->IsConnected()))
         {
-            if (!theApp.serverconnect -> IsConnected() || theApp.serverconnect -> IsLowID() || theApp.listensocket -> TooManySockets())
+            if (!theApp.serverconnect->IsConnected() || theApp.serverconnect->IsLowID() || theApp.listensocket->TooManySockets())
             return 0;
         }
     }
@@ -206,7 +210,7 @@ uint32 CUpDownClient:: GetScore(bool sysvalue, bool isdownloading, bool onlybase
 //   true : Next requested block is from another different chunk or file than last downloaded block
 //   false: Next requested block is from same chunk that last downloaded block
 // [Tarod 12/22/2002]:
-bool CUpDownClient:: IsDifferentPartBlock(void)
+bool CUpDownClient::IsDifferentPartBlock(void)
 {
     Requested_Block_Struct *last_done_block;
     Requested_Block_Struct *next_requested_block;
@@ -222,18 +226,16 @@ bool CUpDownClient:: IsDifferentPartBlock(void)
             last_done_block = (Requested_Block_Struct *) m_DoneBlocks_list.GetHead();
             next_requested_block = (Requested_Block_Struct *) m_BlockRequests_queue.GetHead();
             // Calculate corresponding parts to blocks
-            last_done_part = last_done_block -> StartOffset / PARTSIZE;
-            next_requested_part = next_requested_block -> StartOffset / PARTSIZE;
+            last_done_part = last_done_block->StartOffset / PARTSIZE;
+            next_requested_part = next_requested_block->StartOffset / PARTSIZE;
             // Test is we are asking same file and same part
             if (last_done_part != next_requested_part)
             {
                 different_part = true;
-                theApp.xmuledlg -> AddDebugLogLine(false, "Session ended due to new chunk.");
             }
-            if (memcmp(last_done_block -> FileID, next_requested_block -> FileID, 16) != 0)
+            if (memcmp(last_done_block->FileID, next_requested_block->FileID, 16) != 0)
             {
                 different_part = true;
-                theApp.xmuledlg -> AddDebugLogLine(false, "Session ended due to different file.");
             }
         }
     }
@@ -241,34 +243,33 @@ bool CUpDownClient:: IsDifferentPartBlock(void)
     {
         different_part = true;
     }
-    //	theApp.xmuledlg->AddDebugLogLine(false, "Debug: User %s, last_done_part (%u) %s (%u) next_requested_part, sent %u Kbs.", GetUserName(), last_done_part, different_part? "!=": "==", next_requested_part, this->GetTransferedUp() / 1024);
     return different_part;
 }
 
-bool CUpDownClient:: CreateNextBlockPackage()
+bool CUpDownClient::CreateNextBlockPackage()
 {
     // time critical
     // check if we should kick this client
     // VQB Full Chunk Trans..
-    if (theApp.glob_prefs -> TransferFullChunks())
+    if (theApp.dynprefs->Get<bool>("transfer-full-chunks") == true)
     {
         // VQB to provide full chunk transfers (modified by Tarod)
-        if (theApp.uploadqueue -> CheckForTimeOver(this) || IsDifferentPartBlock())
+        if (theApp.uploadqueue->CheckForTimeOver(this) || IsDifferentPartBlock())
         {
             SetWaitStartTime();
-            theApp.uploadqueue -> RemoveFromUploadQueue(this);
-            theApp.uploadqueue -> AddClientToQueue(this, true);
+            theApp.uploadqueue->RemoveFromUploadQueue(this);
+            theApp.uploadqueue->AddClientToQueue(this, true);
             return false;
         }
     }
     else
     {
-        if (theApp.uploadqueue -> CheckForTimeOver(this))
+        if (theApp.uploadqueue->CheckForTimeOver(this))
         {
             // back on the waitqueue
             SetWaitStartTime();
-            theApp.uploadqueue -> RemoveFromUploadQueue(this);
-            theApp.uploadqueue -> AddClientToQueue(this, true);
+            theApp.uploadqueue->RemoveFromUploadQueue(this);
+            theApp.uploadqueue->AddClientToQueue(this, true);
             return false;
         }
     }
@@ -284,40 +285,40 @@ bool CUpDownClient:: CreateNextBlockPackage()
         while (!m_BlockRequests_queue.IsEmpty())
         {
             Requested_Block_Struct *currentblock = m_BlockRequests_queue.GetHead();
-            CKnownFile *srcfile = theApp.sharedfiles -> GetFileByID(currentblock -> FileID);
+            CKnownFile *srcfile = theApp.sharedfiles->GetFileByID(currentblock->FileID);
             if (!srcfile)
             throw GetResString(IDS_ERR_REQ_FNF);
-            if (srcfile -> IsPartFile() && ((CPartFile *) srcfile) -> GetStatus() != PS_COMPLETE)
+            if (srcfile->IsPartFile() && ((CPartFile *) srcfile)->GetStatus() != PS_COMPLETE)
             {
-                fullname = nstrdup(((CPartFile *) srcfile) -> GetFullName());
+                fullname = nstrdup(((CPartFile *) srcfile)->GetFullName());
                 fullname[strlen(fullname) - 4] = 0;
             }
             else
             {
-                fullname = new char[strlen(srcfile -> GetPath()) + strlen(srcfile -> GetFileName()) + 10];
-                sprintf(fullname, "%s/%s", srcfile -> GetPath(), srcfile -> GetFileName());
+                fullname = new char[strlen(srcfile->GetPath()) + strlen(srcfile->GetFileName()) + 10];
+                sprintf(fullname, "%s/%s", srcfile->GetPath(), srcfile->GetFileName());
             }
             uint32 togo;
-            if (currentblock -> StartOffset > currentblock -> EndOffset)
+            if (currentblock->StartOffset > currentblock->EndOffset)
             {
-                togo = currentblock -> EndOffset + (srcfile -> GetFileSize() - currentblock -> StartOffset);
+                togo = currentblock->EndOffset + (srcfile->GetFileSize() - currentblock->StartOffset);
             }
             else
             {
-                togo = currentblock -> EndOffset - currentblock -> StartOffset;
-                if (srcfile -> IsPartFile() && ! ((CPartFile *) srcfile) -> IsComplete(currentblock -> StartOffset, currentblock -> EndOffset - 1))
+                togo = currentblock->EndOffset - currentblock->StartOffset;
+                if (srcfile->IsPartFile() && ! ((CPartFile *) srcfile)->IsComplete(currentblock->StartOffset, currentblock->EndOffset - 1))
                 throw GetResString(IDS_ERR_INCOMPLETEBLOCK);
             }
             if (togo > 184320)
             throw GetResString(IDS_ERR_LARGEREQBLOCK);
-            if (!srcfile -> IsPartFile())
+            if (!srcfile->IsPartFile())
             {
                 //CFile::modeRead|CFile::osSequentialScan|CFile::shareDenyNone)):
-                if (!file.Open(fullname, CFile:: read))
+                if (!file.Open(fullname, CFile::read))
                 throw GetResString(IDS_ERR_OPEN);
                 delete[] fullname;
                 fullname = 0;
-                file.Seek(currentblock -> StartOffset);
+                file.Seek(currentblock->StartOffset);
                 filedata = new byte[togo + 500];
                 if (uint32 done = file.Read(filedata, togo) != togo)
                 {
@@ -331,21 +332,21 @@ bool CUpDownClient:: CreateNextBlockPackage()
                 CPartFile *partfile = (CPartFile *) srcfile;
                 delete[] fullname;
                 fullname = 0;
-                partfile -> m_hpartfile.Seek(currentblock -> StartOffset);
+                partfile->m_hpartfile.Seek(currentblock->StartOffset);
                 filedata = new byte[togo + 500];
-                if (uint32 done = partfile -> m_hpartfile.Read(filedata, togo) != togo)
+                if (uint32 done = partfile->m_hpartfile.Read(filedata, togo) != togo)
                 {
-                    partfile -> m_hpartfile.Seek(0);
-                    partfile -> m_hpartfile.Read(filedata + done, togo - done);
+                    partfile->m_hpartfile.Seek(0);
+                    partfile->m_hpartfile.Read(filedata + done, togo - done);
                 }
             }
-            SetUploadFileID(currentblock -> FileID);
-            if (m_byDataCompVer == 1 && (!strstr(srcfile -> GetFileName(), ".zip")) && (!strstr(srcfile -> GetFileName(), ".rar")) && (!strstr(srcfile -> GetFileName(), ".ace")))
+            SetUploadFileID(currentblock->FileID);
+            if (m_byDataCompVer == 1 && (!strstr(srcfile->GetFileName(), ".zip")) && (!strstr(srcfile->GetFileName(), ".rar")) && (!strstr(srcfile->GetFileName(), ".ace")))
             CreatePackedPackets(filedata, togo, currentblock);
             else
             CreateStandartPackets(filedata, togo, currentblock);
             // file statistic
-            srcfile -> statistic.AddTransferred(togo);
+            srcfile->statistic.AddTransferred(togo);
             m_DoneBlocks_list.AddHead(m_BlockRequests_queue.RemoveHead());
             delete[] filedata;
             filedata = 0;
@@ -353,19 +354,17 @@ bool CUpDownClient:: CreateNextBlockPackage()
     }
     catch(wxString error)
     {
-        theApp.xmuledlg -> AddDebugLogLine(false, GetResString(IDS_ERR_CLIENTERRORED), GetUserName(), error.GetData());
-        theApp.uploadqueue -> RemoveFromUploadQueue(this);
+        theApp.uploadqueue->RemoveFromUploadQueue(this);
         if (filedata)
         delete filedata;
         if (fullname)
         delete[] fullname;
         return false;
     }
-    //	theApp.xmuledlg->AddDebugLogLine(false,"Debug: Packet done. Size: %i",blockpack->GetLength());
     return true;
 }
 
-void CUpDownClient:: ProcessUpFileStatus(char *packet, uint32 size)
+void CUpDownClient::ProcessUpFileStatus(char *packet, uint32 size)
 {
     if (m_abyUpPartStatus)
     {
@@ -378,18 +377,18 @@ void CUpDownClient:: ProcessUpFileStatus(char *packet, uint32 size)
     return;
     CSafeMemFile *data = new CSafeMemFile((BYTE *) packet, size);
     uchar cfilehash[16];
-    data -> Read(cfilehash, 16);
-    CKnownFile *tempreqfile = theApp.sharedfiles -> GetFileByID(cfilehash);
-    data -> Read( &m_nUpPartCount, 2);
+    data->Read(cfilehash, 16);
+    CKnownFile *tempreqfile = theApp.sharedfiles->GetFileByID(cfilehash);
+    data->Read( &m_nUpPartCount, 2);
     if (!m_nUpPartCount)
     {
-        m_nUpPartCount = tempreqfile -> GetPartCount();
+        m_nUpPartCount = tempreqfile->GetPartCount();
         m_abyUpPartStatus = new uint8[m_nUpPartCount];
         memset(m_abyUpPartStatus, 0, m_nUpPartCount);
     }
     else
     {
-        if (tempreqfile -> GetPartCount() != m_nUpPartCount)
+        if (tempreqfile->GetPartCount() != m_nUpPartCount)
         {
             //mf:
             delete data;
@@ -401,7 +400,7 @@ void CUpDownClient:: ProcessUpFileStatus(char *packet, uint32 size)
         while (done != m_nUpPartCount)
         {
             uint8 toread;
-            data -> Read( &toread, 1);
+            data->Read( &toread, 1);
             for (sint32 i = 0 ; i != 8 ; i++)
             {
                 m_abyUpPartStatus[done] = ((toread >> i) &1) ? 1: 0;
@@ -414,12 +413,12 @@ void CUpDownClient:: ProcessUpFileStatus(char *packet, uint32 size)
             }
         }
     }
-    tempreqfile -> NewAvailPartsInfo();
-    theApp.xmuledlg -> transferwnd -> queuelistctrl -> RefreshClient(this);
+    tempreqfile->NewAvailPartsInfo();
+    theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(this);
     delete data;
 }
 
-void CUpDownClient:: CreateStandartPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
+void CUpDownClient::CreateStandartPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
 {
     uint32 nPacketSize;
     CMemFile memfile((BYTE *) data, togo);
@@ -433,17 +432,17 @@ void CUpDownClient:: CreateStandartPackets(byte *data, uint32 togo, Requested_Bl
         nPacketSize = togo;
         togo -= nPacketSize;
         Packet *packet = new Packet(OP_SENDINGPART, nPacketSize + 24);
-        memcpy( &packet -> pBuffer[0], GetUploadFileID(), 16);
-        uint32 statpos = (currentblock -> EndOffset - togo) - nPacketSize;
-        memcpy( &packet -> pBuffer[16], &statpos, 4);
-        uint32 endpos = (currentblock -> EndOffset - togo);
-        memcpy( &packet -> pBuffer[20], &endpos, 4);
-        memfile.Read( &packet -> pBuffer[24], nPacketSize);
+        memcpy( &packet->pBuffer[0], GetUploadFileID(), 16);
+        uint32 statpos = (currentblock->EndOffset - togo) - nPacketSize;
+        memcpy( &packet->pBuffer[16], &statpos, 4);
+        uint32 endpos = (currentblock->EndOffset - togo);
+        memcpy( &packet->pBuffer[20], &endpos, 4);
+        memfile.Read( &packet->pBuffer[24], nPacketSize);
         m_BlockSend_queue.AddTail(packet);
     }
 }
 
-void CUpDownClient:: CreatePackedPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
+void CUpDownClient::CreatePackedPackets(byte *data, uint32 togo, Requested_Block_Struct *currentblock)
 {
     BYTE *output = new BYTE[togo + 300];
     uLongf newsize = togo + 300;
@@ -468,28 +467,28 @@ void CUpDownClient:: CreatePackedPackets(byte *data, uint32 togo, Requested_Bloc
         nPacketSize = togo;
         togo -= nPacketSize;
         Packet *packet = new Packet(OP_COMPRESSEDPART, nPacketSize + 24, OP_EMULEPROT);
-        memcpy( &packet -> pBuffer[0], GetUploadFileID(), 16);
-        uint32 statpos = currentblock -> StartOffset;
-        memcpy( &packet -> pBuffer[16], &statpos, 4);
-        memcpy( &packet -> pBuffer[20], &newsize, 4);
-        memfile.Read( &packet -> pBuffer[24], nPacketSize);
+        memcpy( &packet->pBuffer[0], GetUploadFileID(), 16);
+        uint32 statpos = currentblock->StartOffset;
+        memcpy( &packet->pBuffer[16], &statpos, 4);
+        memcpy( &packet->pBuffer[20], &newsize, 4);
+        memfile.Read( &packet->pBuffer[24], nPacketSize);
         m_BlockSend_queue.AddTail(packet);
     }
     delete[] output;
 }
 
-void CUpDownClient:: SetUploadFileID(uchar *tempreqfileid)
+void CUpDownClient::SetUploadFileID(uchar *tempreqfileid)
 {
     CKnownFile *newreqfile = NULL;
     if (tempreqfileid)
-    newreqfile = theApp.sharedfiles -> GetFileByID(tempreqfileid);
-    CKnownFile *oldreqfile = theApp.sharedfiles -> GetFileByID(requpfileid);
+    newreqfile = theApp.sharedfiles->GetFileByID(tempreqfileid);
+    CKnownFile *oldreqfile = theApp.sharedfiles->GetFileByID(requpfileid);
     if (newreqfile == oldreqfile)
     return;
     if (newreqfile)
     {
-        newreqfile -> AddQueuedCount();
-        newreqfile -> AddUploadingClient(this);
+        newreqfile->AddQueuedCount();
+        newreqfile->AddUploadingClient(this);
         memcpy(requpfileid, tempreqfileid, 16);
     }
     else
@@ -498,16 +497,16 @@ void CUpDownClient:: SetUploadFileID(uchar *tempreqfileid)
     }
     if (oldreqfile)
     {
-        oldreqfile -> SubQueuedCount();
-        oldreqfile -> RemoveUploadingClient(this);
+        oldreqfile->SubQueuedCount();
+        oldreqfile->RemoveUploadingClient(this);
     }
 }
 
-void CUpDownClient:: AddReqBlock(Requested_Block_Struct *reqblock)
+void CUpDownClient::AddReqBlock(Requested_Block_Struct *reqblock)
 {
     for (POSITION pos = m_DoneBlocks_list.GetHeadPosition() ; pos != 0 ; m_DoneBlocks_list.GetNext(pos))
     {
-        if (reqblock -> StartOffset == m_DoneBlocks_list.GetAt(pos) -> StartOffset &&reqblock -> EndOffset == m_DoneBlocks_list.GetAt(pos) -> EndOffset)
+        if (reqblock->StartOffset == m_DoneBlocks_list.GetAt(pos)->StartOffset &&reqblock->EndOffset == m_DoneBlocks_list.GetAt(pos)->EndOffset)
         {
             delete reqblock;
             return;
@@ -515,7 +514,7 @@ void CUpDownClient:: AddReqBlock(Requested_Block_Struct *reqblock)
     }
     for (POSITION pos = m_BlockRequests_queue.GetHeadPosition() ; pos != 0 ; m_BlockRequests_queue.GetNext(pos))
     {
-        if (reqblock -> StartOffset == m_BlockRequests_queue.GetAt(pos) -> StartOffset &&reqblock -> EndOffset == m_BlockRequests_queue.GetAt(pos) -> EndOffset)
+        if (reqblock->StartOffset == m_BlockRequests_queue.GetAt(pos)->StartOffset &&reqblock->EndOffset == m_BlockRequests_queue.GetAt(pos)->EndOffset)
         {
             delete reqblock;
             return;
@@ -524,25 +523,25 @@ void CUpDownClient:: AddReqBlock(Requested_Block_Struct *reqblock)
     m_BlockRequests_queue.AddTail(reqblock);
 }
 
-void CUpDownClient:: SetUpStartTime(uint32 dwTime)
+void CUpDownClient::SetUpStartTime(uint32 dwTime)
 {
     if (dwTime)
     m_dwUploadTime = dwTime;
     else
-    m_dwUploadTime =:: GetTickCount();
+    m_dwUploadTime =::GetTickCount();
 }
 
-void CUpDownClient:: SetWaitStartTime(uint32 dwTime)
+void CUpDownClient::SetWaitStartTime(uint32 dwTime)
 {
     if (dwTime)
     m_dwWaitTime = dwTime;
     else
-    m_dwWaitTime =:: GetTickCount();
+    m_dwWaitTime =::GetTickCount();
 }
 
-uint32 CUpDownClient:: SendBlockData(uint32 nMaxAmmount)
+uint32 CUpDownClient::SendBlockData(uint32 nMaxAmmount)
 {
-    uint32 msCur =:: GetTickCount();
+    uint32 msCur =::GetTickCount();
     uint32 bytesToSend = 0;
     float lambdaAvg, kBpsToSend;
     m_AvarageUDR_list.AddTail(dataratems);
@@ -563,20 +562,20 @@ uint32 CUpDownClient:: SendBlockData(uint32 nMaxAmmount)
     if (m_cSendblock == 30)
     {
         m_cSendblock = 0;
-        theApp.xmuledlg -> transferwnd -> uploadlistctrl -> RefreshClient(this);
+        theApp.xmuledlg->transferwnd->uploadlistctrl->RefreshClient(this);
     }
     dataratems = 0;
-    if (socket && !socket -> IsBusy())
+    if (socket && !socket->IsBusy())
     {
         if (!m_BlockSend_queue.IsEmpty() ||CreateNextBlockPackage())
         {
             m_nMaxSendAllowed += nMaxAmmount;
-            if (m_BlockSend_queue.GetHead() -> GetRealPacketSize() > 0
-            &&m_BlockSend_queue.GetHead() -> GetRealPacketSize() > MAXFRAGSIZE *2)
+            if (m_BlockSend_queue.GetHead()->GetRealPacketSize() > 0
+            &&m_BlockSend_queue.GetHead()->GetRealPacketSize() > MAXFRAGSIZE *2)
             {
                 // splitting packets
-                uint32 nSize = m_BlockSend_queue.GetHead() -> GetRealPacketSize();
-                char *pBuffer = m_BlockSend_queue.GetHead() -> DetachPacket();
+                uint32 nSize = m_BlockSend_queue.GetHead()->GetRealPacketSize();
+                char *pBuffer = m_BlockSend_queue.GetHead()->DetachPacket();
                 delete m_BlockSend_queue.RemoveHead();
                 uint32 nPos = nSize;
                 bool bLast = true;
@@ -592,18 +591,18 @@ uint32 CUpDownClient:: SendBlockData(uint32 nMaxAmmount)
                 delete[] pBuffer;
             }
             while (!m_BlockSend_queue.IsEmpty()
-            &&m_BlockSend_queue.GetHead() -> GetRealPacketSize() <= m_nMaxSendAllowed)
+            &&m_BlockSend_queue.GetHead()->GetRealPacketSize() <= m_nMaxSendAllowed)
             {
                 Packet *tosend = m_BlockSend_queue.RemoveHead();
-                uint32 nBlockSize = tosend -> GetRealPacketSize();
+                wxUint32 nBlockSize = tosend->GetRealPacketSize();
                 m_nMaxSendAllowed -= nBlockSize;
-                //printf("CUpDownClient::SendBlockData -> %02x size=%d\n",tosend->opcode,tosend->size);
-                socket -> SendPacket(tosend, true, false);
+                NewSocket_SendPacket(0, tosend, (wxUint32) this, nBlockSize);
                 m_nTransferedUp += nBlockSize;
-                theApp.UpdateSentBytes(nBlockSize);
-                credits -> AddUploaded(nBlockSize);
+                credits->AddUploaded(nBlockSize, GetIP());
                 if (m_BlockSend_queue.IsEmpty())
-                CreateNextBlockPackage();
+                {
+                    CreateNextBlockPackage();
+                }
             }
             dataratems = nMaxAmmount;
             bytesToSend = nMaxAmmount;
@@ -620,47 +619,36 @@ uint32 CUpDownClient:: SendBlockData(uint32 nMaxAmmount)
     return bytesToSend;
 }
 
-void CUpDownClient:: FlushSendBlocks()
+void CUpDownClient::FlushSendBlocks()
 {
     // call this when you stop upload, or the socket might be not able to send
     bool bBreak = false;
-    while (!m_BlockSend_queue.IsEmpty() &&m_BlockSend_queue.GetHead() -> IsSplitted() &&socket &&socket -> IsConnected() && !bBreak)
+    while (!m_BlockSend_queue.IsEmpty() &&m_BlockSend_queue.GetHead()->IsSplitted() &&socket &&socket->IsConnected() && !bBreak)
     {
         Packet *tosend = m_BlockSend_queue.RemoveHead();
-        bool bBreak = tosend -> IsLastSplitted();
-        theApp.uploadqueue -> AddUpDataOverheadOther(tosend -> size);
-#if defined(__DEBUG__)
-        printf("CUpDownClient::FlushSendBlocks -> %02x size=%d\n", tosend -> opcode, tosend -> size);
-#endif
-        socket -> SendPacket(tosend, true, false);
+        bool bBreak = tosend->IsLastSplitted();
+        NewSocket_SendPacket(0, tosend, (wxUint32) this, 0);
     }
 }
 
-void CUpDownClient:: SendHashsetPacket(char *forfileid)
+void CUpDownClient::SendHashsetPacket(char *forfileid)
 {
-    CKnownFile *file = theApp.sharedfiles -> GetFileByID((uchar *) forfileid);
-    if (!file)
+    CKnownFile *file = theApp.sharedfiles->GetFileByID((uchar *) forfileid);
+    if (file)
     {
-        theApp.xmuledlg -> AddLogLine(false, GetResString(IDS_ERR_REQ_FNF));
-        return;
+        CMemFile *data = new CMemFile();
+        data->Write(file->GetFileHash(), 16);
+        uint16 parts = file->GetHashCount();
+        data->Write( &parts, 2);
+        for (int i = 0 ; i != parts ; i++)
+        data->Write(file->GetPartHash(i), 16);
+        Packet *packet = new Packet(data);
+        NewSocket_SendPacketOP(2,OP_HASHSETANSWER, packet, (wxUint32) this, 1);
+        delete data;
     }
-    CMemFile *data = new CMemFile();
-    data -> Write(file -> GetFileHash(), 16);
-    uint16 parts = file -> GetHashCount();
-    data -> Write( &parts, 2);
-    for (int i = 0 ; i != parts ; i++)
-    data -> Write(file -> GetPartHash(i), 16);
-    Packet *packet = new Packet(data);
-    packet -> opcode = OP_HASHSETANSWER;
-    delete data;
-    theApp.uploadqueue -> AddUpDataOverheadFileRequest(packet -> size);
-#if defined(__DEBUG__)
-    printf("CUpDownClient::SendHashsetPacket--> OP_HASHSETANSWER size=%d\n", packet -> size);
-#endif
-    socket -> SendPacket(packet, true, true);
 }
 
-void CUpDownClient:: ClearUploadBlockRequests()
+void CUpDownClient::ClearUploadBlockRequests()
 {
     FlushSendBlocks();
     for (POSITION pos = m_BlockRequests_queue.GetHeadPosition() ; pos != 0 ; m_BlockRequests_queue.GetNext(pos))
@@ -680,116 +668,116 @@ void CUpDownClient:: ClearUploadBlockRequests()
     m_BlockSend_queue.RemoveAll();
 }
 
-void CUpDownClient:: SendRankingInfo()
+void CUpDownClient::SendRankingInfo()
 {
-    if (!ExtProtocolAvailable())
-    return;
-    uint16 nRank = theApp.uploadqueue -> GetWaitingPosition(this);
-    if (!nRank)
-    return;
-    Packet *packet = new Packet(OP_QUEUERANKING, 12, OP_EMULEPROT);
-    memset(packet -> pBuffer, 0, 12);
-    memcpy(packet -> pBuffer + 0, &nRank, 2);
-    theApp.uploadqueue -> AddUpDataOverheadOther(packet -> size);
-#if defined(__DEBUG__)
-    printf("CUpDownClient::SendRankingInfo--> OP_QUEUERANKING size=%d\n", packet -> size);
-#endif
-    socket -> SendPacket(packet, true, true);
+    if (ExtProtocolAvailable())
+    {
+        uint16 nRank = theApp.uploadqueue->GetWaitingPosition(this);
+        if (nRank)
+        {
+            Packet *packet = new Packet(OP_QUEUERANKING, 12, OP_EMULEPROT);
+            memset(packet->pBuffer, 0, 12);
+            memcpy(packet->pBuffer + 0, &nRank, 2);
+            NewSocket_SendPacketOP(2, OP_QUEUERANKING,packet, (wxUint32) this, 0);
+        }
+    }
 }
 
-void CUpDownClient:: SendCommentInfo(CKnownFile *file)
+void CUpDownClient::SendCommentInfo(CKnownFile *file)
 {
-    if (!m_bCommentDirty || file == NULL || !ExtProtocolAvailable() || m_byAcceptCommentVer < 1)
-    return;
-    m_bCommentDirty = false;
-    int8 rating = file -> GetFileRate();
-    CString desc = file -> GetFileComment();
-    if (file -> GetFileRate() == 0 &&desc.IsEmpty())
-    return;
-    CMemFile *data = new CMemFile();
-    data -> Write( &rating, sizeof(rating));
-    int length = desc.GetLength();
-    if (length > 128) length = 128;
-    data -> Write( &length, sizeof(length));
-    if (length > 0) data -> Write(desc.GetBuffer(), length);
-    Packet *packet = new Packet(data, OP_EMULEPROT);
-    packet -> opcode = OP_FILEDESC;
-    delete data;
-    theApp.uploadqueue -> AddUpDataOverheadOther(packet -> size);
+    if (m_bCommentDirty && (file != NULL) &&ExtProtocolAvailable() && (m_byAcceptCommentVer > 0))
+    {
+        m_bCommentDirty = false;
+        int8 rating = file->GetFileRate();
+        CString desc = file->GetFileComment();
+        if (file->GetFileRate() || (!desc.IsEmpty()))
+        {
 #if defined(__DEBUG__)
-    printf("CUpDownClient::SendCommentInfo--> OP_FILEDESC size=%d\n", packet -> size);
+            printf("CUpDownClient::SendCommentInfo\n");
 #endif
-    socket -> SendPacket(packet, true);
+            CMemFile *data = new CMemFile();
+            data->Write( &rating, sizeof(rating));
+            int length = desc.GetLength();
+            if (length > 128)
+            {
+                length = 128;
+            }
+            data->Write( &length, sizeof(length));
+            if (length > 0)
+            {
+                data->Write(desc.GetBuffer(), length);
+            }
+            Packet *packet = new Packet(data, OP_EMULEPROT);
+            delete data;
+            NewSocket_SendPacketOP(2,OP_FILEDESC, packet, (wxUint32) this, 0);
+        }
+    }
 }
 
-void CUpDownClient:: AddRequestCount(uchar *fileid)
+void CUpDownClient::AddRequestCount(uchar *fileid)
 {
     for (POSITION pos = m_RequestedFiles_list.GetHeadPosition() ; pos != 0 ; m_RequestedFiles_list.GetNext(pos))
     {
         Requested_File_Struct *cur_struct = m_RequestedFiles_list.GetAt(pos);
-        if (!memcmp(cur_struct -> fileid, fileid, 16))
+        if (!memcmp(cur_struct->fileid, fileid, 16))
         {
-            if (:: GetTickCount() - cur_struct -> lastasked < MIN_REQUESTTIME && !GetFriendSlot())
+            if (::GetTickCount() - cur_struct->lastasked < MIN_REQUESTTIME && !GetFriendSlot())
             {
                 if (GetDownloadState() != DS_DOWNLOADING)
-                cur_struct -> badrequests++;
-                if (cur_struct -> badrequests == BADCLIENTBAN)
+                cur_struct->badrequests++;
+                if (cur_struct->badrequests == BADCLIENTBAN)
                 {
                     Ban();
                 }
             }
             else
             {
-                if (cur_struct -> badrequests)
-                cur_struct -> badrequests--;
+                if (cur_struct->badrequests)
+                cur_struct->badrequests--;
             }
-            cur_struct -> lastasked =:: GetTickCount();
+            cur_struct->lastasked =::GetTickCount();
             return;
         }
     }
     Requested_File_Struct *new_struct = new Requested_File_Struct;
     memset(new_struct, 0, sizeof(Requested_File_Struct));
-    memcpy(new_struct -> fileid, fileid, 16);
-    new_struct -> lastasked =:: GetTickCount();
+    memcpy(new_struct->fileid, fileid, 16);
+    new_struct->lastasked =::GetTickCount();
     m_RequestedFiles_list.AddHead(new_struct);
 }
 
-void CUpDownClient:: UnBan()
+void CUpDownClient::UnBan()
 {
     m_bBanned = false;
     m_dwBanTime = 0;
     SetWaitStartTime();
-    theApp.uploadqueue -> UpdateBanCount();
-    theApp.xmuledlg -> transferwnd -> ShowQueueCount(theApp.uploadqueue -> GetWaitingUserCount());
+    theApp.uploadqueue->UpdateBanCount();
+    theApp.xmuledlg->transferwnd->ShowQueueCount(theApp.uploadqueue->GetWaitingUserCount());
     for (POSITION pos = m_RequestedFiles_list.GetHeadPosition() ; pos != 0 ; m_RequestedFiles_list.GetNext(pos))
     {
         Requested_File_Struct *cur_struct = m_RequestedFiles_list.GetAt(pos);
-        cur_struct -> badrequests = 0;
-        cur_struct -> lastasked = 0;
+        cur_struct->badrequests = 0;
+        cur_struct->lastasked = 0;
     }
     //theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(this, true, true);
 }
 
-void CUpDownClient:: Ban()
+void CUpDownClient::Ban()
 {
     m_bBanned = true;
-    theApp.uploadqueue -> UpdateBanCount();
-    theApp.xmuledlg -> transferwnd -> ShowQueueCount(theApp.uploadqueue -> GetWaitingUserCount());
-    m_dwBanTime =:: GetTickCount();
-    theApp.xmuledlg -> transferwnd -> queuelistctrl -> RefreshClient(this);
-    theApp.xmuledlg -> AddDebugLogLine(false, GetResString(IDS_CLIENTBLOCKED), GetUserName());
+    theApp.uploadqueue->UpdateBanCount();
+    theApp.xmuledlg->transferwnd->ShowQueueCount(theApp.uploadqueue->GetWaitingUserCount());
+    m_dwBanTime =::GetTickCount();
+    theApp.xmuledlg->transferwnd->queuelistctrl->RefreshClient(this);
 }
 
-void CUpDownClient:: UDPFileReasked()
+void CUpDownClient::UDPFileReasked()
 {
     AddAskedCount();
     SetLastUpRequest();
-    uint16 nRank = theApp.uploadqueue -> GetWaitingPosition(this);
+    uint16 nRank = theApp.uploadqueue->GetWaitingPosition(this);
     Packet *response = new Packet(OP_REASKACK, 2, OP_EMULEPROT);
-    memcpy(response -> pBuffer, &nRank, 2);
-#if defined(__DEBUG__)
-    printf("CUpDownClient::UDPFileReasked--> OP_REASKACK size=%d\n", response -> size);
-#endif
-    NewSocket_SendPacket(1,response, GetIP(), GetUDPPort());
+    memcpy(response->pBuffer, &nRank, 2);
+    NewSocket_SendPacket(1, response, GetIP(), GetUDPPort());
 }
 
