@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -51,9 +51,9 @@ static char THIS_FILE[] = __FILE__;
 // to avoid storing in the windows-directory
     /*static*/
 
-    void CIni:: AddModulPath(wxString &strFileName, BOOL bModulPath /*= TRUE*/
+    void CIni::AddModulPath(wxString &strFileName, bool bModulPath /*= TRUE*/
 
-) 
+)
 {
 #if 0
     char drive[_MAX_DRIVE];
@@ -61,16 +61,16 @@ static char THIS_FILE[] = __FILE__;
     char fname[_MAX_FNAME];
     char ext[_MAX_EXT];
     _splitpath(strFileName, drive, dir, fname, ext);
-    if (! drive[0]) 
+    if (! drive[0])
     {
         //PathCanonicalize(..) doesn't work with for all Plattforms !
         wxString strModule;
-        if (bModulPath) 
+        if (bModulPath)
         {
             GetModuleFileName(NULL, strModule.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
             strModule.ReleaseBuffer();
         }
-        else 
+        else
         {
             GetCurrentDirectory(MAX_INI_BUFFER, strModule.GetBuffer(MAX_INI_BUFFER));
             strModule.ReleaseBuffer();
@@ -91,7 +91,7 @@ static char THIS_FILE[] = __FILE__;
 
     /*static*/
 
-wxString CIni:: GetDefaultSection() 
+wxString CIni::GetDefaultSection()
 {
     return wxString("eMule");
     //   return AfxGetAppName();
@@ -99,9 +99,9 @@ wxString CIni:: GetDefaultSection()
 
     /*static*/
 
-    wxString CIni:: GetDefaultIniFile(BOOL bModulPath /*= TRUE*/
+    wxString CIni::GetDefaultIniFile(bool bModulPath /*= TRUE*/
 
-) 
+)
 {
 #if 0
     char drive[_MAX_DRIVE];
@@ -117,13 +117,13 @@ wxString CIni:: GetDefaultSection()
     strTemp = fname;
     //"ApplName.ini":
     strTemp += ".ini";
-    if (bModulPath) 
+    if (bModulPath)
     {
         strApplName = drive;
         strApplName += dir;
         strApplName += strTemp;
     }
-    else 
+    else
     {
         GetCurrentDirectory(MAX_INI_BUFFER, strApplName.GetBuffer(MAX_INI_BUFFER));
         strApplName.ReleaseBuffer();
@@ -141,21 +141,21 @@ wxString CIni:: GetDefaultSection()
 // Konstruktion/Destruktion
 //////////////////////////////////////////////////////////////////////
 // Creates/Use file : "Drive:\ApplPath\ApplName.ini"
-    CIni:: CIni(BOOL bModulPath /*= TRUE*/
+    CIni::CIni(bool bModulPath /*= TRUE*/
 
 ):
-m_bModulPath(bModulPath) 
+m_bModulPath(bModulPath)
 {
     m_strFileName = GetDefaultIniFile(m_bModulPath);
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(CIni const &Ini, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(CIni const &Ini, bool bModulPath /*= TRUE*/
 
 ):
 m_strFileName(Ini.m_strFileName),
 m_strSection(Ini.m_strSection),
-m_bModulPath(Ini.m_bModulPath) 
+m_bModulPath(Ini.m_bModulPath)
 {
     if (m_strFileName.IsEmpty())
     m_strFileName = GetDefaultIniFile(m_bModulPath);
@@ -164,11 +164,11 @@ m_bModulPath(Ini.m_bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(wxString const &strFileName, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, bool bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
-m_bModulPath(bModulPath) 
+m_bModulPath(bModulPath)
 {
     if (m_strFileName.IsEmpty())
     m_strFileName = GetDefaultIniFile(m_bModulPath);
@@ -176,12 +176,12 @@ m_bModulPath(bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-    CIni:: CIni(wxString const &strFileName, wxString const &strSection, BOOL bModulPath /*= TRUE*/
+    CIni::CIni(wxString const &strFileName, wxString const &strSection, bool bModulPath /*= TRUE*/
 
 ):
 m_strFileName(strFileName),
 m_strSection(strSection),
-m_bModulPath(bModulPath) 
+m_bModulPath(bModulPath)
 {
     if (m_strFileName.IsEmpty())
     m_strFileName = GetDefaultIniFile(m_bModulPath);
@@ -190,30 +190,30 @@ m_bModulPath(bModulPath)
     m_strSection = GetDefaultSection();
 }
 
-CIni:: ~CIni() 
+CIni::~CIni()
 {
 }
 
 //////////////////////////////////////////////////////////////////////
 // Zugriff auf Quelle/Ziel von IO-Operationen
 //////////////////////////////////////////////////////////////////////
-void CIni:: SetFileName(wxString const &strFileName) 
+void CIni::SetFileName(wxString const &strFileName)
 {
     m_strFileName = strFileName;
     AddModulPath(m_strFileName);
 }
 
-void CIni:: SetSection(wxString const &strSection) 
+void CIni::SetSection(wxString const &strSection)
 {
     m_strSection = strSection;
 }
 
-wxString const &CIni:: GetFileName() const 
+wxString const &CIni::GetFileName() const
 {
     return m_strFileName;
 }
 
-wxString const &CIni:: GetSection() const 
+wxString const &CIni::GetSection() const
 {
     return m_strSection;
 }
@@ -222,9 +222,9 @@ wxString const &CIni:: GetSection() const
 //
 //////////////////////////////////////////////////////////////////////
 
-    void CIni:: Init(LPCSTR strFileName, LPCSTR strSection/* = NULL*/
+    void CIni::Init(LPCSTR strFileName, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -232,11 +232,11 @@ wxString const &CIni:: GetSection() const
     m_strFileName = strFileName;
 }
 
-    wxString CIni:: GetString(wxString strEntry, LPCSTR strDefault/*=NULL*/
+    wxString CIni::GetString(wxString strEntry, LPCSTR strDefault/*=NULL*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strDefault == NULL)
     return wxString(GetLPCSTR(strEntry, strSection, ""));
@@ -244,83 +244,83 @@ wxString const &CIni:: GetSection() const
     return wxString(GetLPCSTR(strEntry, strSection, strDefault));
 }
 
-    double CIni:: GetDouble(wxString strEntry, double fDefault/* = 0.0*/
+    double CIni::GetDouble(wxString strEntry, double fDefault/* = 0.0*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     wxString strDefault;
     //strDefault.Format("%g",fDefault);
-    strDefault = wxString:: Format("%g", fDefault);
+    strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return atof(m_chBuffer);
 }
 
-    float CIni:: GetFloat(wxString strEntry, float fDefault/* = 0.0*/
+    float CIni::GetFloat(wxString strEntry, float fDefault/* = 0.0*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     wxString strDefault;
     //strDefault.Format("%g",fDefault);
-    strDefault = wxString:: Format("%g", fDefault);
+    strDefault = wxString::Format("%g", fDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(float) atof(m_chBuffer);
 }
 
-    int CIni:: GetInt(wxString strEntry, int nDefault/* = 0*/
+    int CIni::GetInt(wxString strEntry, int nDefault/* = 0*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     wxString strDefault;
     //strDefault.Format("%d",nDefault);
-    strDefault = wxString:: Format("%d", nDefault);
+    strDefault = wxString::Format("%d", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault.GetData());
     return atoi(m_chBuffer);
 }
 
-    WORD CIni:: GetWORD(wxString strEntry, WORD nDefault/* = 0*/
+    WORD CIni::GetWORD(wxString strEntry, WORD nDefault/* = 0*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     wxString strDefault;
     //strDefault.Format("%u",nDefault);
-    strDefault = wxString:: Format("%u", nDefault);
+    strDefault = wxString::Format("%u", nDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(WORD) atoi(m_chBuffer);
 }
 
-    BOOL CIni:: GetBool(wxString strEntry, BOOL bDefault/* = FALSE*/
+    bool CIni::GetBool(wxString strEntry, bool bDefault/* = FALSE*/
 
     , LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     wxString strDefault;
     //strDefault.Format("%d",bDefault);
-    strDefault = wxString:: Format("%d", bDefault);
+    strDefault = wxString::Format("%d", bDefault);
     GetLPCSTR(strEntry, strSection, strDefault);
     return(atoi(m_chBuffer) != 0);
 }
 
-wxPoint CIni:: GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection) 
+wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
 {
     wxPoint ptReturn = ptDefault;
     wxString strDefault;
-    strDefault = wxString:: Format("(%d,%d)", ptDefault.x, ptDefault.y);
+    strDefault = wxString::Format("(%d,%d)", ptDefault.x, ptDefault.y);
     //strDefault.Format("(%d,%d)",ptDefault.x, ptDefault.y);
     wxString strPoint = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strPoint, "(%d,%d)", &ptReturn.x, &ptReturn.y);
     return ptReturn;
 }
 
-wxRect CIni:: GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection) 
+wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
 {
 #if 0
     wxRect rectReturn = rectDefault;
@@ -339,105 +339,104 @@ wxRect CIni:: GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
     return wxRect(0, 0, 0, 0);
 }
 
-COLORREF CIni:: GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSection) 
+COLORREF CIni::GetColRef(wxString strEntry, COLORREF crDefault, LPCSTR strSection)
 {
-    int temp[3] = 
+    int temp[3] =
     {
         GetRValue(crDefault),
         GetGValue(crDefault),
         GetBValue(crDefault)
-    }
-    ;
+        };
     wxString strDefault;
-    strDefault = wxString:: Format("RGB(%hd,%hd,%hd)", temp[0], temp[1], temp[2]);
+    strDefault = wxString::Format("RGB(%hd,%hd,%hd)", temp[0], temp[1], temp[2]);
     wxString strColRef = GetString(strEntry, (char *) strDefault.GetData());
     sscanf(strColRef, "RGB(%d,%d,%d)", temp, temp + 1, temp + 2);
     return RGB(temp[0], temp[1], temp[2]);
 }
 
-void WritePrivateProfileString(const char *sec, const char *entry, const char *jottae, const char *d) 
+void WritePrivateProfileString(const char *sec, const char *entry, const char *jottae, const char *d)
 {
     char buffer[512];
     sprintf(buffer, "%s/%s", sec, entry);
-    wxConfigBase *cb = wxConfigBase:: Get(TRUE);
-    cb -> Write(buffer, jottae);
-    cb -> Flush();
+    wxConfigBase *cb = wxConfigBase::Get(TRUE);
+    cb->Write(buffer, jottae);
+    cb->Flush();
 }
 
-    void CIni:: WriteString(wxString strEntry, wxString str, LPCSTR strSection/* = NULL*/
+    void CIni::WriteString(wxString strEntry, wxString str, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     WritePrivateProfileString(m_strSection, strEntry, str, m_strFileName);
 }
 
-    void CIni:: WriteDouble(wxString strEntry, double f, LPCSTR strSection/*= NULL*/
+    void CIni::WriteDouble(wxString strEntry, double f, LPCSTR strSection/*= NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%g", f);
+    strBuffer = wxString::Format("%g", f);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteFloat(wxString strEntry, float f, LPCSTR strSection/* = NULL*/
+    void CIni::WriteFloat(wxString strEntry, float f, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%g", f);
+    strBuffer = wxString::Format("%g", f);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteInt(wxString strEntry, int n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteInt(wxString strEntry, int n, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%d", n);
+    strBuffer = wxString::Format("%d", n);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteWORD(wxString strEntry, WORD n, LPCSTR strSection/* = NULL*/
+    void CIni::WriteWORD(wxString strEntry, WORD n, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%u", n);
+    strBuffer = wxString::Format("%u", n);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-    void CIni:: WriteBool(wxString strEntry, BOOL b, LPCSTR strSection/* = NULL*/
+    void CIni::WriteBool(wxString strEntry, bool b, LPCSTR strSection/* = NULL*/
 
-) 
+)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("%d", b);
+    strBuffer = wxString::Format("%d", b);
     WritePrivateProfileString(m_strSection, strEntry, strBuffer, m_strFileName);
 }
 
-void CIni:: WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection) 
+void CIni::WritePoint(wxString strEntry, wxPoint pt, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("(%d,%d)", pt.x, pt.y);
+    strBuffer = wxString::Format("(%d,%d)", pt.x, pt.y);
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni:: WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection) 
+void CIni::WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
@@ -446,24 +445,24 @@ void CIni:: WriteRect(wxString strEntry, wxRect rect, LPCSTR strSection)
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-void CIni:: WriteColRef(wxString strEntry, COLORREF cr, LPCSTR strSection) 
+void CIni::WriteColRef(wxString strEntry, COLORREF cr, LPCSTR strSection)
 {
     if (strSection != NULL)
     m_strSection = strSection;
     wxString strBuffer;
-    strBuffer = wxString:: Format("RGB(%d,%d,%d)", GetRValue(cr), GetGValue(cr), GetBValue(cr));
+    strBuffer = wxString::Format("RGB(%d,%d,%d)", GetRValue(cr), GetGValue(cr), GetBValue(cr));
     Write(m_strFileName, m_strSection, strEntry, strBuffer);
 }
 
-wxChar *CIni:: GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxChar *strDefault) 
+wxChar *CIni::GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxChar *strDefault)
 {
-    wxConfigBase *cb = wxConfigBase:: Get(TRUE);
+    wxConfigBase *cb = wxConfigBase::Get(TRUE);
     char buffer[512];
     if (strSection)
     m_strSection = wxString(strSection);
     sprintf(buffer, "%s/%s", m_strSection.GetData(), strEntry.GetData());
-    wxString stringu = cb -> Read(wxString(buffer), wxString(strDefault));
-    cb -> Flush();
+    wxString stringu = cb->Read(wxString(buffer), wxString(strDefault));
+    cb->Flush();
     memcpy(m_chBuffer, stringu.GetData(), stringu.Length() + 1);
     return m_chBuffer;
 #if 0
@@ -480,7 +479,7 @@ wxChar *CIni:: GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxCh
 #endif
 }
 
-void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault) 
+void CIni::SerGetString(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
 {
     if (bGet)
     str = GetString(strEntry, strDefault/*=NULL*/
@@ -491,11 +490,11 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetDouble(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDouble(bool bGet, double &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , double fDefault/* = 0.0*/
 
-) 
+)
 {
     if (bGet)
     f = GetDouble(strEntry, fDefault/*=NULL*/
@@ -506,11 +505,11 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetFloat(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetFloat(bool bGet, float &f, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , float fDefault/* = 0.0*/
 
-) 
+)
 {
     if (bGet)
     f = GetFloat(strEntry, fDefault/*=NULL*/
@@ -521,11 +520,11 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetInt(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetInt(bool bGet, int &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , int nDefault/* = 0*/
 
-) 
+)
 {
     if (bGet)
     n = GetInt(strEntry, nDefault/*=NULL*/
@@ -536,11 +535,11 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetDWORD(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetDWORD(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/* = NULL*/
 
     , DWORD nDefault/* = 0*/
 
-) 
+)
 {
     if (bGet)
     n = (DWORD) GetInt(strEntry, nDefault/*=NULL*/
@@ -551,11 +550,11 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-    void CIni:: SerGetBool(BOOL bGet, BOOL &b, wxString strEntry, LPCSTR strSection/* = NULL*/
+    void CIni::SerGetBool(bool bGet, bool &b, wxString strEntry, LPCSTR strSection/* = NULL*/
 
-    , BOOL bDefault/* = FALSE*/
+    , bool bDefault/* = FALSE*/
 
-) 
+)
 {
     if (bGet)
     b = GetBool(strEntry, bDefault/*=NULL*/
@@ -566,7 +565,7 @@ void CIni:: SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR str
     );
 }
 
-void CIni:: SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault) 
+void CIni::SerGetPoint(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection, wxPoint ptDefault)
 {
     if (bGet)
     pt = GetPoint(strEntry, ptDefault, strSection);
@@ -574,7 +573,7 @@ void CIni:: SerGetPoint(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSec
     WritePoint(strEntry, pt, strSection);
 }
 
-void CIni:: SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault) 
+void CIni::SerGetRect(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection, wxRect rectDefault)
 {
     if (bGet)
     rect = GetRect(strEntry, rectDefault, strSection);
@@ -582,7 +581,7 @@ void CIni:: SerGetRect(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSec
     WriteRect(strEntry, rect, strSection);
 }
 
-void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault) 
+void CIni::SerGetColRef(bool bGet, COLORREF &cr, wxString strEntry, LPCSTR strSection, COLORREF crDefault)
 {
     if (bGet)
     cr = GetColRef(strEntry, crDefault, strSection);
@@ -592,121 +591,121 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
 
 // berladene Methoden //////////////////////////////////////////////////////////////////////////////////////////////////77
 // Einfache Typen /////////////////////////////////////////////////////////////////////////////////////////////////////////
-    void CIni:: SerGet(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxString &str, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , LPCSTR strDefault/*= NULL*/
 
-) 
+)
 {
     SerGetString(bGet, str, strEntry, strSection, strDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, double &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , double fDefault/* = 0.0*/
 
-) 
+)
 {
     SerGetDouble(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, float &f, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , float fDefault/* = 0.0*/
 
-) 
+)
 {
     SerGetFloat(bGet, f, strEntry, strSection, fDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, int &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
-) 
+)
 {
     SerGetInt(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, short &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , int nDefault/* = 0*/
 
-) 
+)
 {
     int nTemp = n;
     SerGetInt(bGet, nTemp, strEntry, strSection, nDefault);
     n = nTemp;
 }
 
-    void CIni:: SerGet(BOOL bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, DWORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
-) 
+)
 {
     SerGetDWORD(bGet, n, strEntry, strSection, nDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, WORD &n, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , DWORD nDefault/* = 0*/
 
-) 
+)
 {
     DWORD dwTemp = n;
     SerGetDWORD(bGet, dwTemp, strEntry, strSection, nDefault);
     n = dwTemp;
 }
 
-//	void		SerGet(	BOOL bGet,BOOL		& b,	wxString strEntry,	LPCSTR strSection = NULL,	BOOL bDefault = FALSE);
-    void CIni:: SerGet(BOOL bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
+//	void		SerGet(	bool bGet,bool		& b,	wxString strEntry,	LPCSTR strSection = NULL,	bool bDefault = FALSE);
+    void CIni::SerGet(bool bGet, wxPoint &pt, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxPoint ptDefault/* = wxPoint(0,0)*/
 
-) 
+)
 {
     SerGetPoint(bGet, pt, strEntry, strSection, ptDefault);
 }
 
-    void CIni:: SerGet(BOOL bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
+    void CIni::SerGet(bool bGet, wxRect &rect, wxString strEntry, LPCSTR strSection/*= NULL*/
 
     , wxRect rectDefault/* = wxRect(0,0,0,0)*/
 
-) 
+)
 {
     SerGetRect(bGet, rect, strEntry, strSection, rectDefault);
 }
 
-//	void		SerGet(	BOOL bGet,COLORREF	& cr,	wxString strEntry,	LPCSTR strSection = NULL,	COLORREF crDefault = RGB(128,128,128));
+//	void		SerGet(	bool bGet,COLORREF	& cr,	wxString strEntry,	LPCSTR strSection = NULL,	COLORREF crDefault = RGB(128,128,128));
 
 // berladene Methoden ////////////////////////////////////////////////////////////////////////////////////////////
 // ARRAYS /////////////////////////////////////////////////////////////////////////////////////////////////////////
 // Entries werden durch Unterstrich + Index ergenzt////////////////////////////////////////////////////////////////
-    void CIni:: SerGet(BOOL bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxString *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , LPCSTR Default/*=NULL*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, ar[i]);
                 if (ar[i].Length() == 0)
                 ar[i] = Default;
             }
         }
-        else 
+        else
         {
             strBuffer = ar[0];
-            for (int i = 1 ; i < nCount ; i++) 
+            for (int i = 1 ; i < nCount ; i++)
             {
                 //.AppendChar(',');:
                 strBuffer = strBuffer + ",";
@@ -717,21 +716,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, double *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , double Default/* = 0.0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -740,13 +739,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = atof(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%g", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%g", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%g", ar[i]);
+                strTemp = wxString::Format("%g", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -756,21 +755,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, float *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , float Default/* = 0.0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -779,13 +778,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = (float) atof(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%g", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%g", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%g", ar[i]);
+                strTemp = wxString::Format("%g", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -795,21 +794,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, int *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -818,13 +817,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = atoi(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%d", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -834,21 +833,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, unsigned char *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , unsigned char Default/* = 0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -857,13 +856,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = (unsigned char) atoi(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%d", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -873,21 +872,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, short *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , int Default/* = 0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -896,13 +895,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = (short) atoi(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%d", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -912,21 +911,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, DWORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -935,13 +934,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = (DWORD) atoi(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%d", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -951,21 +950,21 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, WORD *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , DWORD Default/* = 0*/
 
-) 
+)
 {
-    if (nCount > 0) 
+    if (nCount > 0)
     {
         wxString strBuffer;
-        if (bGet) 
+        if (bGet)
         {
             strBuffer = GetString(strEntry, "", strSection);
             wxString strTemp;
             int nOffset = 0;
-            for (int i = 0 ; i < nCount ; i++) 
+            for (int i = 0 ; i < nCount ; i++)
             {
                 nOffset = Parse(strBuffer, nOffset, strTemp);
                 if (strTemp.Length() == 0)
@@ -974,13 +973,13 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
                 ar[i] = (WORD) atoi(strTemp);
             }
         }
-        else 
+        else
         {
             wxString strTemp;
-            strBuffer = wxString:: Format("%d", ar[0]);
-            for (int i = 1 ; i < nCount ; i++) 
+            strBuffer = wxString::Format("%d", ar[0]);
+            for (int i = 1 ; i < nCount ; i++)
             {
-                strTemp = wxString:: Format("%d", ar[i]);
+                strTemp = wxString::Format("%d", ar[i]);
                 //				strBuffer.AppendChar(',');
                 strBuffer = strBuffer + ",";
                 strBuffer.Append(strTemp);
@@ -990,51 +989,51 @@ void CIni:: SerGetColRef(BOOL bGet, COLORREF &cr, wxString strEntry, LPCSTR strS
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxPoint *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxPoint Default/* = wxPoint(0,0)*/
 
-) 
+)
 {
     wxString strBuffer;
-    for (int i = 0 ; i < nCount ; i++) 
+    for (int i = 0 ; i < nCount ; i++)
     {
-        strBuffer = wxString:: Format("_%i", i);
+        strBuffer = wxString::Format("_%i", i);
         strBuffer = strEntry + strBuffer;
         SerGet(bGet, ar[i], strBuffer, strSection, Default);
     }
 }
 
-    void CIni:: SerGet(BOOL bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
+    void CIni::SerGet(bool bGet, wxRect *ar, int nCount, wxString strEntry, LPCSTR strSection/*=NULL*/
 
     , wxRect Default/* = wxRect(0,0,0,0)*/
 
-) 
+)
 {
     wxString strBuffer;
-    for (int i = 0 ; i < nCount ; i++) 
+    for (int i = 0 ; i < nCount ; i++)
     {
-        strBuffer = wxString:: Format("_%i", i);
+        strBuffer = wxString::Format("_%i", i);
         strBuffer = strEntry + strBuffer;
         SerGet(bGet, ar[i], strBuffer, strSection, Default);
     }
 }
 
-int CIni:: Parse(wxString &strIn, int nOffset, wxString &strOut) 
+int CIni::Parse(wxString &strIn, int nOffset, wxString &strOut)
 {
     strOut.Clear();
     int nLength = strIn.Length();
-    if (nOffset < nLength) 
+    if (nOffset < nLength)
     {
         if (nOffset != 0 &&strIn.GetChar(nOffset) == ',')
         nOffset++;
-        while (nOffset < nLength) 
+        while (nOffset < nLength)
         {
             if (!isspace(strIn.GetChar(nOffset)))
             break;
             nOffset++;
         }
-        while (nOffset < nLength) 
+        while (nOffset < nLength)
         {
             strOut += strIn.GetChar(nOffset);
             if (strIn.GetChar(++nOffset) == ',')
@@ -1045,7 +1044,7 @@ int CIni:: Parse(wxString &strIn, int nOffset, wxString &strOut)
     return nOffset;
 }
 
-void GetPrivateProfileString(const wxChar *a0, const wxChar *a, const wxChar *b, wxChar *ret, long len, const wxChar *name) 
+void GetPrivateProfileString(const wxChar *a0, const wxChar *a, const wxChar *b, wxChar *ret, long len, const wxChar *name)
 {
     printf("todo. gpps\n");
 }
@@ -1053,7 +1052,7 @@ void GetPrivateProfileString(const wxChar *a0, const wxChar *a, const wxChar *b,
 //////////////////////////////////////////////////////////////////////
 // statische Methoden
 //////////////////////////////////////////////////////////////////////
-wxString CIni:: Read(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strDefault) 
+wxString CIni::Read(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strDefault)
 {
     wxString strReturn;
     GetPrivateProfileString(strSection,
@@ -1067,7 +1066,7 @@ wxString CIni:: Read(wxString const &strFileName, wxString const &strSection, wx
     return strReturn;
 }
 
-void CIni:: Write(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strValue) 
+void CIni::Write(wxString const &strFileName, wxString const &strSection, wxString const &strEntry, wxString const &strValue)
 {
     WritePrivateProfileString(strSection,
     strEntry,
