@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04.12.99
-// RCS-ID:      $Id: listbase.h,v 1.1.16.1 2004/03/31 05:06:39 plaenky Exp $
+// RCS-ID:      $Id: listbase.h,v 1.14 2004/10/05 04:44:49 HopeSeekr Exp $
 // Copyright:   (c) wxWindows team
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -37,6 +37,8 @@
 
 #if wxUSE_LISTCTRL
 
+#include <wx/colour.h>                      // wxColour
+#include <wx/font.h>                        // wxFont
 // ----------------------------------------------------------------------------
 // types
 // ----------------------------------------------------------------------------
