@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -1113,7 +1113,7 @@
 #define IDC_ADD                         2011
 #define IDC_COLOR_BUTTON                2011
 #define IDC_EDITADR                     2011
-#define IDC_BROWSE                      2011
+//#define IDC_BROWSE                      2011
 #define IDC_RELOADFILTER                2011
 #define IDC_HOTMENU                     2011
 #define IDC_WSRELOADTMPL                2011
@@ -1556,22 +1556,22 @@
 #define IDC_WIZ_TRUEUPLOAD_BOX          2280
 #define IDC_UDPPORT                     2280
 #define IDC_USERNAME                    2280
-#define IDC_CMT_TEXT                    2280
+//#define IDC_CMT_TEXT                    2280
 #define IDC_MAXSRCPERFILESOFT           2280
 #define IDC_MAXSRCEPERFILESOFT          2280
 #define IDC_DEBUG_LOG                   2280
-#define IDC_TITLE                       2280
+//#define IDC_TITLE                       2280
 #define IDC_FILTERLEVEL                 2280
 #define IDC_TEXT                        2280
 #define IDC_WSPORT                      2280
 #define IDC_WIZARD                      2281
 #define IDC_USERHASH                    2281
-#define IDC_INCOMING                    2281
+//#define IDC_INCOMING                    2281
 #define IDC_WSPASS                      2281
 #define IDC_OS_FRAME                    2282
 #define IDC_IP                          2282
 #define IDC_INCOMING2                   2282
-#define IDC_COMMENT                     2282
+//#define IDC_COMMENT                     2282
 #define IDC_WSPASS2                     2282
 #define IDC_WSPASSLOW                   2282
 #define IDC_HOTBUTTON_FRAME             2283
@@ -1647,7 +1647,7 @@
 #define IDC_CLIENTLIST                  2354
 #define IDC_STATIC_FILTERLEVEL2         2354
 #define IDC_EDITFILTER                  2355
-#define IDC_CATCOLOR                    2356
+//#define IDC_CATCOLOR                    2356
 #define IDC_FILTERCOMMENTSLABEL         2357
 #define IDC_WATCHCB                     2358
 #define IDC_STATIC_COLOR                2359
@@ -1726,7 +1726,7 @@
 #define IDD_PPG_SECURITY                2431
 #define IDC_IRC_EMULEPROTO_INFOMESSAGE  2432
 #define IDC_STATIC_PRIO                 2433
-#define IDC_PRIOCOMBO                   2434
+//#define IDC_PRIOCOMBO                   2434
 #define IDR_WIZ1_WATERMARK              2435
 #define IDR_WIZ1_HEADER                 2436
 #define IDC_STARTNEXTFILECAT            2437
