@@ -1,38 +1,46 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
-//This program is free software; you can redistribute it and/or
-//modify it under the terms of the GNU General Public License
-//as published by the Free Software Foundation; either
-//version 2 of the License, or (at your option) any later version.
-//
-//This program is distributed in the hope that it will be useful,
-//but WITHOUT ANY WARRANTY; without even the implied warranty of
-//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//GNU General Public License for more details.
-//
-//You should have received a copy of the GNU General Public License
-//along with this program; if not, write to the Free Software
-//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef _UPDOWNCLIENT_H
 #define _UPDOWNCLIENT_H
 
+#include "mfc.h"                            // CString
 #include "wintypes.h"
 #include "types.h"
-#include "ListenSocket.h"
-//#include "PartFile.h"
-#include "ClientCredits.h"
-#include "SafeFile.h"
+#include "ClientCredits.h"                  // Needed for some unknown reason
 #include "BarShader.h"
-#include "otherfunctions.h"
+#include "otherfunctions.h"                 // Needed for GetTickCount
 
-class CPartFile;
+#include <iostream>                         // std::cout std::endl
+
+class CClientCredits;
 class CKnownFile;
+class CListenSocket;
+class CMemFile;
+class CPartFile;
+class CSafeMemFile;
+class Packet;
+class Pending_Block_Struct;
+class Requested_Block_Struct;
+class Requested_File_Struct;
 typedef unsigned char byte;
 extern inline long GetTickCount();
 
@@ -72,6 +80,7 @@ enum EClientSoftware {
 	SO_EMULE			= 0,
 	SO_CDONKEY			= 1,
 	SO_XMULE			= 2,
+	SO_AMULE			= 3,
 	SO_SHAREAZA			= 4,
 	SO_EDONKEYHYBRID		= 50,
 	SO_EDONKEY			= 51,
@@ -129,10 +138,10 @@ public:
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
 	int			GetHashType();
 	uint32			GetVersion()				{return m_nClientVersion;}
-	uint8			GetMuleVersion()			{return m_byEmuleVersion;}
+	uint8			GetMuleVersion()			{if(m_byEmuleVersion==0x99) return 0x42; else return m_byEmuleVersion;}
 	bool			ExtProtocolAvailable()		{return m_bEmuleProtocol;}
 	bool			IsEmuleClient()				{return m_byEmuleVersion;}
-	CClientCredits* Credits()					{return credits;}
+	CClientCredits* 	Credits()					{return credits;}
 	bool			IsBanned()	{return (m_bBanned && m_nDownloadState != DS_DOWNLOADING);}
 	char*			GetClientFilename()			{return m_pszClientFilename;}
 	wxString		GetClientFilename_NEW() const		{return m_strClientFilename;}
@@ -153,8 +162,8 @@ public:
 	void			SetUserName(char* pszNewName);
 	EClientSoftware		GetClientSoft()				{return m_clientSoft;}
 	void			ReGetClientSoft();
-	void			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
-	void			ProcessHelloPacket(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloPacket(char* pachPacket, uint32 nSize);
 	void			SendHelloAnswer();
 	void			SendHelloPacket();
 	void			SendMuleInfoPacket(bool bAnswer);
@@ -173,9 +182,17 @@ public:
 	void			SetFriendSlot(bool bNV)		{m_bFriendSlot = bNV;}
 	void			SetCommentDirty(bool bDirty = true) {m_bCommentDirty = bDirty;}
 	uint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
+
+	void			SendPublicKeyPacket();
+	void			SendSignaturePacket();
+	void			ProcessPublicKeyPacket(uchar* pachPacket, uint32 nSize);
+	void			ProcessSignaturePacket(uchar* pachPacket, uint32 nSize);
 	uint8			GetSecureIdentState()		{return m_SecureIdentState;}
 	void			SendSecIdentStatePacket();
+	void			ProcessSecIdentStatePacket(unsigned char* pachPacket,wxUint32 nSize);
+	uint8			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
 	void			InfoPacketsReceived();
+	void			ResetFileStatusInfo();
 
 	bool			SupportsPreview()		{return m_bSupportsPreview;}
 	bool			SafeSendPacket(Packet* packet);
@@ -234,9 +251,38 @@ public:
 	uint8			GetDownloadState()			{return m_nDownloadState;}
 	void			SetDownloadState(uint8 byNewState);
 	uint32			GetLastAskedTime()			{return m_dwLastAskedTime;}
-	inline bool			IsPartAvailable(uint16 iPart)	{return	( (iPart >= m_nPartCount) || (!m_abyPartStatus) )? 0:m_abyPartStatus[iPart];}
-	bool			IsUpPartAvailable(uint16 iPart) {return ( (iPart
- >= m_nUpPartCount) || (!m_abyUpPartStatus) )? 0:m_abyUpPartStatus[iPart];}
+	
+    bool IsPartAvailable(uint16 iPart)
+    {
+        bool status = false;
+        try
+        {
+            status = ((iPart >= m_nPartCount) || (!m_abyPartStatus))  ? 0 : m_abyPartStatus[iPart];
+        }
+        catch(...)
+        {
+            std::cout << "Caught deadly error in CUpDownClient::IsPartAvailable(" << iPart << ")!" << std::endl;
+            status = false;
+        }
+
+        return status;
+    }
+
+    bool IsUpPartAvailable(uint16 iPart)
+    {
+        bool status = false;
+        try
+        {
+            status = ((iPart >= m_nUpPartCount) || (!m_abyUpPartStatus))? 0 : m_abyUpPartStatus[iPart];
+        }
+        catch(...)
+        {
+            std::cout << "Caught deadly error in CUpDownClient::IsUpPartAvailable(" << iPart << ")!" << std::endl;
+            status = false;
+        }
+
+        return status;
+    }
 	uint8*			GetPartStatus()				{return m_abyPartStatus;}
 	uint32			GetDownloadDatarate()		{return m_nDownDatarate;}
 	uint16			GetRemoteQueueRank()		{return m_nRemoteQueueRank;}
@@ -256,6 +302,7 @@ public:
 	uint32			CalculateDownloadRate();
 	uint16			GetAvailablePartCount();
 	//			SwapToAnotherFile(bool bIgnoreNoNeeded = false);   Razor 1a - Modif by MikaelB 
+
 	void			UDPReaskACK(uint16 nNewQR);
 	void			UDPReaskFNF();
 	void			UDPReaskForDownload();
@@ -269,6 +316,9 @@ public:
 	//chat
 	uint8			GetChatState()				{return m_byChatstate;}
 	void			SetChatState(uint8 nNewS)	{m_byChatstate = nNewS;}
+	bool			m_bIsSpammer;
+	uint8			m_cMessagesReceived; //Count of chatmessages he sent to me
+	uint8			m_cMessagesSend; //Count of chatmessages i sent to him
 
 	//File Comment 
     CString			GetFileComment()			{return m_strComment;} 
@@ -284,13 +334,14 @@ public:
 	int  GetFileListRequested() { return m_iFileListRequested; }
 	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
 	uint8	m_cFailed;
-
+    bool deletethis;
+    bool SpecialPerson;
 private:
 	CPartFile*		reqfile;
 
 	// base
 	void	Init();
-	void	ProcessHelloTypePacket(CSafeMemFile* data);
+	bool	ProcessHelloTypePacket(CSafeMemFile* data);
 	void	SendHelloTypePacket(CMemFile* data);
 	bool	m_bIsBotuser;
 //	bool	isfriend;
@@ -324,15 +375,21 @@ private:
 	bool	m_bCommentDirty;
 	bool	m_bIsHybrid;
 	bool	m_bIsML;
-	uint32	m_byCompatibleClient;
-	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
-	DWORD	m_lastRefreshedDLDisplay;
+	bool	m_bGPLEvildoer;
+	bool	m_bPreviewReqPending;
+	bool	m_bPreviewAnsPending;
+	uint16	m_nKadPort;
+	bool	m_bMultiPacket;
+
 	ESecureIdentState	m_SecureIdentState;
 	uint8	m_byInfopacketsReceived;
 	uint32	m_dwLastSignatureIP;
 	uint8	m_bySupportSecIdent;
-	bool	m_bSupportsPreview;
+	bool	m_bySupportsPreview;
 	
+	uint32	m_byCompatibleClient;
+	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
+	DWORD	m_lastRefreshedDLDisplay;
 
 	//upload
 	void CreateStandartPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
@@ -355,12 +412,15 @@ private:
 	uint16 m_nUpCompleteSourcesCount;
 	public:
 	uint8*		m_abyUpPartStatus;
+	uint16		m_lastPartAsked;
+	DWORD		m_dwEnteredConnectedState;
+	CString		m_strModVersion;
 	uint32		m_nSumForAvgUpDataRate;
 
 	private:
 	CList<int,int>	 m_AvarageUDR_list;
 	
-	CTypedPtrList<CPtrList, Packet*>				 m_BlockSend_queue;
+	CTypedPtrList<CPtrList, Packet*>	 m_BlockSend_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_BlockRequests_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DoneBlocks_list;
 	CTypedPtrList<CPtrList, Requested_File_Struct*>	 m_RequestedFiles_list;
@@ -387,7 +447,9 @@ private:
 	bool		m_bUDPPending;
 	uint32		m_nSumForAvgDownDataRate;
 	bool		m_bHashsetRequested;
-	bool		m_fSharedDirectories;
+	bool		m_bSharedDirectories;
+ 	bool		m_bNoViewSharedFiles;
+	bool		m_bSupportsPreview;
 
 	CList<int,int>	 m_AvarageDDR_list;
 	sint32		sumavgDDR;
